/// <reference types="react" />
import { VisualElement } from "../VisualElement";
import { AxisBox2D, Point2D, BoxDelta } from "../../types/geometry";
import { ResolvedValues } from "../VisualElement/types";
import { DOMVisualElementConfig, TransformOrigin } from "./types";
import { Presence, SharedLayoutAnimationConfig } from "../../components/AnimateSharedLayout/types";
import { TargetAndTransition, Transition } from "../../types";
import { MotionValue } from "../../value";
import { OnViewportBoxUpdate } from "../../motion/features/layout/types";
export declare type LayoutUpdateHandler = (layout: AxisBox2D, prev: AxisBox2D, config?: SharedLayoutAnimationConfig) => void;
/**
 * A VisualElement for HTMLElements
 */
export declare class HTMLVisualElement<E extends HTMLElement | SVGElement = HTMLElement> extends VisualElement<E> {
    /**
     *
     */
    protected defaultConfig: DOMVisualElementConfig;
    /**
     * A mutable record of styles we want to apply directly to the rendered Element
     * every frame. We use a mutable data structure to reduce GC during animations.
     */
    style: ResolvedValues;
    /**
     * A record of styles we only want to apply via React. This gets set in useMotionValues
     * and applied in the render function. I'd prefer this to live somewhere else to decouple
     * VisualElement from React but works for now.
     */
    reactStyle: ResolvedValues;
    /**
     * A mutable record of CSS variables we want to apply directly to the rendered Element
     * every frame. We use a mutable data structure to reduce GC during animations.
     */
    vars: ResolvedValues;
    /**
     * Presence data. This is hydrated by useDomVisualElement and used by AnimateSharedLayout
     * to decide how to animate entering/exiting layoutId
     */
    presence?: Presence;
    isPresent?: boolean;
    /**
     * A mutable record of transforms we want to apply directly to the rendered Element
     * every frame. We use a mutable data structure to reduce GC during animations.
     */
    protected transform: ResolvedValues;
    /**
     * A mutable record of transform origins we want to apply directly to the rendered Element
     * every frame. We use a mutable data structure to reduce GC during animations.
     */
    protected transformOrigin: TransformOrigin;
    /**
     * A mutable record of transform keys we want to apply to the rendered Element. We order
     * this to order transforms in the desired order. We use a mutable data structure to reduce GC during animations.
     */
    protected transformKeys: string[];
    config: DOMVisualElementConfig;
    /**
     * When a value is removed, we want to make sure it's removed from all rendered data structures.
     */
    removeValue(key: string): void;
    /**
     * Empty the mutable data structures by re-creating them. We can do this every React render
     * as the comparative workload to the rest of the render is very low and this is also when
     * we want to reflect values that might have been removed by the render.
     */
    clean(): void;
    updateConfig(config?: DOMVisualElementConfig): void;
    /**
     * Read a value directly from the HTMLElement style.
     */
    read(key: string): number | string | null;
    addValue(key: string, value: MotionValue): void;
    /**
     * Read a value directly from the HTMLElement in case it's not defined by a Motion
     * prop. If it's a transform, we just return a pre-defined default value as reading these
     * out of a matrix is either error-prone or can incur a big payload for little benefit.
     */
    readNativeValue(key: string): any;
    /**
     * Ensure that HTML and Framer-specific value types like `px`->`%` and `Color`
     * can be animated by Motion.
     */
    makeTargetAnimatable({ transition, transitionEnd, ...target }: TargetAndTransition): {
        alignContent?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | undefined)[]] | undefined;
        alignItems?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[]] | undefined;
        alignSelf?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[]] | undefined;
        animationDelay?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        animationDirection?: import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | (import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | undefined)[]] | undefined;
        animationDuration?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        animationFillMode?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | undefined)[]] | undefined;
        animationIterationCount?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | undefined)[]] | undefined;
        animationName?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        animationPlayState?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | undefined)[]] | undefined;
        animationTimingFunction?: import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        appearance?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "button" | "meter" | "textarea" | "checkbox" | "listbox" | "menulist" | "progress-bar" | "push-button" | "radio" | "searchfield" | "slider-horizontal" | "square-button" | "menulist-button" | "textfield" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "button" | "meter" | "textarea" | "checkbox" | "listbox" | "menulist" | "progress-bar" | "push-button" | "radio" | "searchfield" | "slider-horizontal" | "square-button" | "menulist-button" | "textfield" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "button" | "meter" | "textarea" | "checkbox" | "listbox" | "menulist" | "progress-bar" | "push-button" | "radio" | "searchfield" | "slider-horizontal" | "square-button" | "menulist-button" | "textfield" | undefined)[]] | undefined;
        aspectRatio?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[]] | undefined;
        backdropFilter?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        backfaceVisibility?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "hidden" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "hidden" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "hidden" | undefined)[]] | undefined;
        backgroundAttachment?: import("../../types").CustomValueType | (string & {}) | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "scroll" | "local" | (import("../../types").CustomValueType | (string & {}) | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "scroll" | "local" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "scroll" | "local" | undefined)[]] | undefined;
        backgroundBlendMode?: import("../../types").CustomValueType | (string & {}) | "color" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "color-burn" | "color-dodge" | "darken" | "difference" | "exclusion" | "hard-light" | "hue" | "lighten" | "luminosity" | "multiply" | "overlay" | "saturation" | "screen" | "soft-light" | (import("../../types").CustomValueType | (string & {}) | "color" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "color-burn" | "color-dodge" | "darken" | "difference" | "exclusion" | "hard-light" | "hue" | "lighten" | "luminosity" | "multiply" | "overlay" | "saturation" | "screen" | "soft-light" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "color" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "color-burn" | "color-dodge" | "darken" | "difference" | "exclusion" | "hard-light" | "hue" | "lighten" | "luminosity" | "multiply" | "overlay" | "saturation" | "screen" | "soft-light" | undefined)[]] | undefined;
        backgroundClip?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[]] | undefined;
        backgroundColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        backgroundImage?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        backgroundOrigin?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[]] | undefined;
        backgroundPosition?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        backgroundPositionX?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        backgroundPositionY?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        backgroundRepeat?: import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "repeat-x" | "repeat-y" | "round" | "space" | (import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "repeat-x" | "repeat-y" | "round" | "space" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "repeat-x" | "repeat-y" | "round" | "space" | undefined)[]] | undefined;
        backgroundSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        blockOverflow?: import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | (import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | undefined)[]] | undefined;
        blockSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderBlockColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        borderBlockEndColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        borderBlockEndStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        borderBlockEndWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        borderBlockStartColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        borderBlockStartStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        borderBlockStartWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        borderBlockStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        borderBlockWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        borderBottomColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        borderBottomLeftRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderBottomRightRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderBottomStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        borderBottomWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        borderCollapse?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "collapse" | "separate" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "collapse" | "separate" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "collapse" | "separate" | undefined)[]] | undefined;
        borderEndEndRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderEndStartRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderImageOutset?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        borderImageRepeat?: import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "round" | "space" | "stretch" | (import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "round" | "space" | "stretch" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "round" | "space" | "stretch" | undefined)[]] | undefined;
        borderImageSlice?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        borderImageSource?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        borderImageWidth?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        borderInlineColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        borderInlineEndColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        borderInlineEndStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        borderInlineEndWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        borderInlineStartColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        borderInlineStartStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        borderInlineStartWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        borderInlineStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        borderInlineWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        borderLeftColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        borderLeftStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        borderLeftWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        borderRightColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        borderRightStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        borderRightWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        borderSpacing?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderStartEndRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderStartStartRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderTopColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        borderTopLeftRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderTopRightRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderTopStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        borderTopWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        bottom?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        boxDecorationBreak?: import("../../types").CustomValueType | "slice" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "clone" | (import("../../types").CustomValueType | "slice" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "clone" | undefined)[] | [null, ...(import("../../types").CustomValueType | "slice" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "clone" | undefined)[]] | undefined;
        boxShadow?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        boxSizing?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | undefined)[]] | undefined;
        breakAfter?: import("../../types").CustomValueType | "left" | "right" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "avoid-column" | "avoid-page" | "avoid-region" | "column" | "page" | "recto" | "region" | "verso" | (import("../../types").CustomValueType | "left" | "right" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "avoid-column" | "avoid-page" | "avoid-region" | "column" | "page" | "recto" | "region" | "verso" | undefined)[] | [null, ...(import("../../types").CustomValueType | "left" | "right" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "avoid-column" | "avoid-page" | "avoid-region" | "column" | "page" | "recto" | "region" | "verso" | undefined)[]] | undefined;
        breakBefore?: import("../../types").CustomValueType | "left" | "right" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "avoid-column" | "avoid-page" | "avoid-region" | "column" | "page" | "recto" | "region" | "verso" | (import("../../types").CustomValueType | "left" | "right" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "avoid-column" | "avoid-page" | "avoid-region" | "column" | "page" | "recto" | "region" | "verso" | undefined)[] | [null, ...(import("../../types").CustomValueType | "left" | "right" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "avoid-column" | "avoid-page" | "avoid-region" | "column" | "page" | "recto" | "region" | "verso" | undefined)[]] | undefined;
        breakInside?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "avoid" | "avoid-column" | "avoid-page" | "avoid-region" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "avoid" | "avoid-column" | "avoid-page" | "avoid-region" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "avoid" | "avoid-column" | "avoid-page" | "avoid-region" | undefined)[]] | undefined;
        captionSide?: import("../../types").CustomValueType | "bottom" | "top" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "block-end" | "block-start" | "inline-end" | "inline-start" | (import("../../types").CustomValueType | "bottom" | "top" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "block-end" | "block-start" | "inline-end" | "inline-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "bottom" | "top" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "block-end" | "block-start" | "inline-end" | "inline-start" | undefined)[]] | undefined;
        caretColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "auto" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "auto" | undefined)[]] | undefined;
        clear?: import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "both" | "inline-end" | "inline-start" | (import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "both" | "inline-end" | "inline-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "both" | "inline-end" | "inline-start" | undefined)[]] | undefined;
        clipPath?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | undefined)[]] | undefined;
        color?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        colorAdjust?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "economy" | "exact" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "economy" | "exact" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "economy" | "exact" | undefined)[]] | undefined;
        columnCount?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        columnFill?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "balance" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "balance" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "balance" | undefined)[]] | undefined;
        columnGap?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        columnRuleColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        columnRuleStyle?: import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        columnRuleWidth?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        columnSpan?: import("../../types").CustomValueType | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        columnWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        contain?: import("../../types").CustomValueType | (string & {}) | "content" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "style" | "layout" | "size" | "paint" | "strict" | (import("../../types").CustomValueType | (string & {}) | "content" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "style" | "layout" | "size" | "paint" | "strict" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "content" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "style" | "layout" | "size" | "paint" | "strict" | undefined)[]] | undefined;
        content?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "contents" | "normal" | "close-quote" | "no-close-quote" | "no-open-quote" | "open-quote" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "contents" | "normal" | "close-quote" | "no-close-quote" | "no-open-quote" | "open-quote" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "contents" | "normal" | "close-quote" | "no-close-quote" | "no-open-quote" | "open-quote" | undefined)[]] | undefined;
        counterIncrement?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        counterReset?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        counterSet?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        cursor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "-moz-grab" | "-webkit-grab" | "alias" | "all-scroll" | "auto" | "cell" | "col-resize" | "context-menu" | "copy" | "crosshair" | "default" | "e-resize" | "ew-resize" | "grab" | "grabbing" | "help" | "move" | "n-resize" | "ne-resize" | "nesw-resize" | "no-drop" | "not-allowed" | "ns-resize" | "nw-resize" | "nwse-resize" | "pointer" | "progress" | "row-resize" | "s-resize" | "se-resize" | "sw-resize" | "text" | "vertical-text" | "w-resize" | "wait" | "zoom-in" | "zoom-out" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "-moz-grab" | "-webkit-grab" | "alias" | "all-scroll" | "auto" | "cell" | "col-resize" | "context-menu" | "copy" | "crosshair" | "default" | "e-resize" | "ew-resize" | "grab" | "grabbing" | "help" | "move" | "n-resize" | "ne-resize" | "nesw-resize" | "no-drop" | "not-allowed" | "ns-resize" | "nw-resize" | "nwse-resize" | "pointer" | "progress" | "row-resize" | "s-resize" | "se-resize" | "sw-resize" | "text" | "vertical-text" | "w-resize" | "wait" | "zoom-in" | "zoom-out" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "-moz-grab" | "-webkit-grab" | "alias" | "all-scroll" | "auto" | "cell" | "col-resize" | "context-menu" | "copy" | "crosshair" | "default" | "e-resize" | "ew-resize" | "grab" | "grabbing" | "help" | "move" | "n-resize" | "ne-resize" | "nesw-resize" | "no-drop" | "not-allowed" | "ns-resize" | "nw-resize" | "nwse-resize" | "pointer" | "progress" | "row-resize" | "s-resize" | "se-resize" | "sw-resize" | "text" | "vertical-text" | "w-resize" | "wait" | "zoom-in" | "zoom-out" | undefined)[]] | undefined;
        direction?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ltr" | "rtl" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ltr" | "rtl" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ltr" | "rtl" | undefined)[]] | undefined;
        display?: import("../../types").CustomValueType | (string & {}) | "flex" | "grid" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "run-in" | "-ms-flexbox" | "-ms-grid" | "-webkit-flex" | "flow" | "flow-root" | "ruby" | "table" | "ruby-base" | "ruby-base-container" | "ruby-text" | "ruby-text-container" | "table-caption" | "table-cell" | "table-column" | "table-column-group" | "table-footer-group" | "table-header-group" | "table-row" | "table-row-group" | "-ms-inline-flexbox" | "-ms-inline-grid" | "-webkit-inline-flex" | "inline-block" | "inline-flex" | "inline-grid" | "inline-list-item" | "inline-table" | "contents" | "list-item" | (import("../../types").CustomValueType | (string & {}) | "flex" | "grid" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "run-in" | "-ms-flexbox" | "-ms-grid" | "-webkit-flex" | "flow" | "flow-root" | "ruby" | "table" | "ruby-base" | "ruby-base-container" | "ruby-text" | "ruby-text-container" | "table-caption" | "table-cell" | "table-column" | "table-column-group" | "table-footer-group" | "table-header-group" | "table-row" | "table-row-group" | "-ms-inline-flexbox" | "-ms-inline-grid" | "-webkit-inline-flex" | "inline-block" | "inline-flex" | "inline-grid" | "inline-list-item" | "inline-table" | "contents" | "list-item" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "flex" | "grid" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "run-in" | "-ms-flexbox" | "-ms-grid" | "-webkit-flex" | "flow" | "flow-root" | "ruby" | "table" | "ruby-base" | "ruby-base-container" | "ruby-text" | "ruby-text-container" | "table-caption" | "table-cell" | "table-column" | "table-column-group" | "table-footer-group" | "table-header-group" | "table-row" | "table-row-group" | "-ms-inline-flexbox" | "-ms-inline-grid" | "-webkit-inline-flex" | "inline-block" | "inline-flex" | "inline-grid" | "inline-list-item" | "inline-table" | "contents" | "list-item" | undefined)[]] | undefined;
        emptyCells?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "hide" | "show" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "hide" | "show" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "hide" | "show" | undefined)[]] | undefined;
        filter?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        flexBasis?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        flexDirection?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | undefined)[]] | undefined;
        flexGrow?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        flexShrink?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        flexWrap?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "nowrap" | "wrap" | "wrap-reverse" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "nowrap" | "wrap" | "wrap-reverse" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "nowrap" | "wrap" | "wrap-reverse" | undefined)[]] | undefined;
        float?: import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "inline-end" | "inline-start" | (import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "inline-end" | "inline-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "inline-end" | "inline-start" | undefined)[]] | undefined;
        fontFamily?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "cursive" | "fantasy" | "monospace" | "sans-serif" | "serif" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "cursive" | "fantasy" | "monospace" | "sans-serif" | "serif" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "cursive" | "fantasy" | "monospace" | "sans-serif" | "serif" | undefined)[]] | undefined;
        fontFeatureSettings?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[]] | undefined;
        fontKerning?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "normal" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "normal" | undefined)[]] | undefined;
        fontLanguageOverride?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[]] | undefined;
        fontOpticalSizing?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        fontSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        fontSizeAdjust?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | undefined)[]] | undefined;
        fontSmooth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        fontStretch?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "condensed" | "expanded" | "extra-condensed" | "extra-expanded" | "normal" | "semi-condensed" | "semi-expanded" | "ultra-condensed" | "ultra-expanded" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "condensed" | "expanded" | "extra-condensed" | "extra-expanded" | "normal" | "semi-condensed" | "semi-expanded" | "ultra-condensed" | "ultra-expanded" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "condensed" | "expanded" | "extra-condensed" | "extra-expanded" | "normal" | "semi-condensed" | "semi-expanded" | "ultra-condensed" | "ultra-expanded" | undefined)[]] | undefined;
        fontStyle?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "italic" | "oblique" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "italic" | "oblique" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "italic" | "oblique" | undefined)[]] | undefined;
        fontSynthesis?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "style" | "weight" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "style" | "weight" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "style" | "weight" | undefined)[]] | undefined;
        fontVariant?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ruby" | "normal" | "jis04" | "jis78" | "jis83" | "jis90" | "simplified" | "traditional" | "all-petite-caps" | "all-small-caps" | "common-ligatures" | "contextual" | "diagonal-fractions" | "discretionary-ligatures" | "full-width" | "historical-forms" | "historical-ligatures" | "lining-nums" | "no-common-ligatures" | "no-contextual" | "no-discretionary-ligatures" | "no-historical-ligatures" | "oldstyle-nums" | "ordinal" | "petite-caps" | "proportional-nums" | "proportional-width" | "slashed-zero" | "small-caps" | "stacked-fractions" | "tabular-nums" | "titling-caps" | "unicase" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ruby" | "normal" | "jis04" | "jis78" | "jis83" | "jis90" | "simplified" | "traditional" | "all-petite-caps" | "all-small-caps" | "common-ligatures" | "contextual" | "diagonal-fractions" | "discretionary-ligatures" | "full-width" | "historical-forms" | "historical-ligatures" | "lining-nums" | "no-common-ligatures" | "no-contextual" | "no-discretionary-ligatures" | "no-historical-ligatures" | "oldstyle-nums" | "ordinal" | "petite-caps" | "proportional-nums" | "proportional-width" | "slashed-zero" | "small-caps" | "stacked-fractions" | "tabular-nums" | "titling-caps" | "unicase" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ruby" | "normal" | "jis04" | "jis78" | "jis83" | "jis90" | "simplified" | "traditional" | "all-petite-caps" | "all-small-caps" | "common-ligatures" | "contextual" | "diagonal-fractions" | "discretionary-ligatures" | "full-width" | "historical-forms" | "historical-ligatures" | "lining-nums" | "no-common-ligatures" | "no-contextual" | "no-discretionary-ligatures" | "no-historical-ligatures" | "oldstyle-nums" | "ordinal" | "petite-caps" | "proportional-nums" | "proportional-width" | "slashed-zero" | "small-caps" | "stacked-fractions" | "tabular-nums" | "titling-caps" | "unicase" | undefined)[]] | undefined;
        fontVariantCaps?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "all-petite-caps" | "all-small-caps" | "petite-caps" | "small-caps" | "titling-caps" | "unicase" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "all-petite-caps" | "all-small-caps" | "petite-caps" | "small-caps" | "titling-caps" | "unicase" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "all-petite-caps" | "all-small-caps" | "petite-caps" | "small-caps" | "titling-caps" | "unicase" | undefined)[]] | undefined;
        fontVariantEastAsian?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ruby" | "normal" | "jis04" | "jis78" | "jis83" | "jis90" | "simplified" | "traditional" | "full-width" | "proportional-width" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ruby" | "normal" | "jis04" | "jis78" | "jis83" | "jis90" | "simplified" | "traditional" | "full-width" | "proportional-width" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ruby" | "normal" | "jis04" | "jis78" | "jis83" | "jis90" | "simplified" | "traditional" | "full-width" | "proportional-width" | undefined)[]] | undefined;
        fontVariantLigatures?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "normal" | "common-ligatures" | "contextual" | "discretionary-ligatures" | "historical-ligatures" | "no-common-ligatures" | "no-contextual" | "no-discretionary-ligatures" | "no-historical-ligatures" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "normal" | "common-ligatures" | "contextual" | "discretionary-ligatures" | "historical-ligatures" | "no-common-ligatures" | "no-contextual" | "no-discretionary-ligatures" | "no-historical-ligatures" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "normal" | "common-ligatures" | "contextual" | "discretionary-ligatures" | "historical-ligatures" | "no-common-ligatures" | "no-contextual" | "no-discretionary-ligatures" | "no-historical-ligatures" | undefined)[]] | undefined;
        fontVariantNumeric?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "diagonal-fractions" | "lining-nums" | "oldstyle-nums" | "ordinal" | "proportional-nums" | "slashed-zero" | "stacked-fractions" | "tabular-nums" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "diagonal-fractions" | "lining-nums" | "oldstyle-nums" | "ordinal" | "proportional-nums" | "slashed-zero" | "stacked-fractions" | "tabular-nums" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "diagonal-fractions" | "lining-nums" | "oldstyle-nums" | "ordinal" | "proportional-nums" | "slashed-zero" | "stacked-fractions" | "tabular-nums" | undefined)[]] | undefined;
        fontVariantPosition?: import("../../types").CustomValueType | "sub" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "super" | (import("../../types").CustomValueType | "sub" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "super" | undefined)[] | [null, ...(import("../../types").CustomValueType | "sub" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "super" | undefined)[]] | undefined;
        fontVariationSettings?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[]] | undefined;
        fontWeight?: import("../../types").CustomValueType | "bold" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "normal" | "bolder" | "lighter" | (import("../../types").CustomValueType | "bold" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "normal" | "bolder" | "lighter" | undefined)[] | [null, ...(import("../../types").CustomValueType | "bold" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "normal" | "bolder" | "lighter" | undefined)[]] | undefined;
        gridAutoColumns?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        gridAutoFlow?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "row" | "dense" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "row" | "dense" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "row" | "dense" | undefined)[]] | undefined;
        gridAutoRows?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        gridColumnEnd?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        gridColumnStart?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        gridRowEnd?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        gridRowStart?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        gridTemplateAreas?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        gridTemplateColumns?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        gridTemplateRows?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        hangingPunctuation?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "allow-end" | "first" | "force-end" | "last" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "allow-end" | "first" | "force-end" | "last" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "allow-end" | "first" | "force-end" | "last" | undefined)[]] | undefined;
        height?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        hyphens?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | undefined)[]] | undefined;
        imageOrientation?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flip" | "from-image" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flip" | "from-image" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flip" | "from-image" | undefined)[]] | undefined;
        imageRendering?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "-moz-crisp-edges" | "-webkit-optimize-contrast" | "crisp-edges" | "pixelated" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "-moz-crisp-edges" | "-webkit-optimize-contrast" | "crisp-edges" | "pixelated" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "-moz-crisp-edges" | "-webkit-optimize-contrast" | "crisp-edges" | "pixelated" | undefined)[]] | undefined;
        imageResolution?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "from-image" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "from-image" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "from-image" | undefined)[]] | undefined;
        initialLetter?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "normal" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "normal" | undefined)[]] | undefined;
        inlineSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        inset?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        insetBlock?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        insetBlockEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        insetBlockStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        insetInline?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        insetInlineEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        insetInlineStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        isolation?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "isolate" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "isolate" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "isolate" | undefined)[]] | undefined;
        justifyContent?: import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | (import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | undefined)[]] | undefined;
        justifyItems?: import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | "legacy" | (import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | "legacy" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | "legacy" | undefined)[]] | undefined;
        justifySelf?: import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | (import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[]] | undefined;
        left?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        letterSpacing?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        lineBreak?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | undefined)[]] | undefined;
        lineHeight?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        lineHeightStep?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        listStyleImage?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        listStylePosition?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "inside" | "outside" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "inside" | "outside" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "inside" | "outside" | undefined)[]] | undefined;
        listStyleType?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        marginBlock?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        marginBlockEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        marginBlockStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        marginBottom?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        marginInline?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        marginInlineEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        marginInlineStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        marginLeft?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        marginRight?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        marginTop?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        maskBorderMode?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "alpha" | "luminance" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "alpha" | "luminance" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "alpha" | "luminance" | undefined)[]] | undefined;
        maskBorderOutset?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        maskBorderRepeat?: import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "round" | "space" | "stretch" | (import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "round" | "space" | "stretch" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "round" | "space" | "stretch" | undefined)[]] | undefined;
        maskBorderSlice?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        maskBorderSource?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        maskBorderWidth?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        maskClip?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "no-clip" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "no-clip" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "no-clip" | undefined)[]] | undefined;
        maskComposite?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "add" | "exclude" | "intersect" | "subtract" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "add" | "exclude" | "intersect" | "subtract" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "add" | "exclude" | "intersect" | "subtract" | undefined)[]] | undefined;
        maskImage?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        maskMode?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "alpha" | "luminance" | "match-source" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "alpha" | "luminance" | "match-source" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "alpha" | "luminance" | "match-source" | undefined)[]] | undefined;
        maskOrigin?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "margin-box" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "margin-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "margin-box" | undefined)[]] | undefined;
        maskPosition?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        maskRepeat?: import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "repeat-x" | "repeat-y" | "round" | "space" | (import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "repeat-x" | "repeat-y" | "round" | "space" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "repeat-x" | "repeat-y" | "round" | "space" | undefined)[]] | undefined;
        maskSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        maskType?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "alpha" | "luminance" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "alpha" | "luminance" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "alpha" | "luminance" | undefined)[]] | undefined;
        maxBlockSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        maxHeight?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        maxInlineSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        maxLines?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | undefined)[]] | undefined;
        maxWidth?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        minBlockSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        minHeight?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        minInlineSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        minWidth?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        mixBlendMode?: import("../../types").CustomValueType | "color" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "color-burn" | "color-dodge" | "darken" | "difference" | "exclusion" | "hard-light" | "hue" | "lighten" | "luminosity" | "multiply" | "overlay" | "saturation" | "screen" | "soft-light" | (import("../../types").CustomValueType | "color" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "color-burn" | "color-dodge" | "darken" | "difference" | "exclusion" | "hard-light" | "hue" | "lighten" | "luminosity" | "multiply" | "overlay" | "saturation" | "screen" | "soft-light" | undefined)[] | [null, ...(import("../../types").CustomValueType | "color" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "color-burn" | "color-dodge" | "darken" | "difference" | "exclusion" | "hard-light" | "hue" | "lighten" | "luminosity" | "multiply" | "overlay" | "saturation" | "screen" | "soft-light" | undefined)[]] | undefined;
        motionDistance?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        motionPath?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | undefined)[]] | undefined;
        motionRotation?: import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[]] | undefined;
        objectFit?: import("../../types").CustomValueType | "contain" | "fill" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "cover" | "scale-down" | (import("../../types").CustomValueType | "contain" | "fill" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "cover" | "scale-down" | undefined)[] | [null, ...(import("../../types").CustomValueType | "contain" | "fill" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "cover" | "scale-down" | undefined)[]] | undefined;
        objectPosition?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        offsetAnchor?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        offsetDistance?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        offsetPath?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | undefined)[]] | undefined;
        offsetRotate?: import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[]] | undefined;
        offsetRotation?: import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[]] | undefined;
        opacity?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        order?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        orphans?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        outlineColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "invert" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "invert" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "invert" | undefined)[]] | undefined;
        outlineOffset?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        outlineStyle?: import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        outlineWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        overflowAnchor?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        overflowBlock?: import("../../types").CustomValueType | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | (import("../../types").CustomValueType | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[] | [null, ...(import("../../types").CustomValueType | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[]] | undefined;
        overflowClipBox?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "content-box" | "padding-box" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "content-box" | "padding-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "content-box" | "padding-box" | undefined)[]] | undefined;
        overflowInline?: import("../../types").CustomValueType | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | (import("../../types").CustomValueType | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[] | [null, ...(import("../../types").CustomValueType | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[]] | undefined;
        overflowWrap?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "anywhere" | "break-word" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "anywhere" | "break-word" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "anywhere" | "break-word" | undefined)[]] | undefined;
        overflowX?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[]] | undefined;
        overflowY?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[]] | undefined;
        overscrollBehavior?: import("../../types").CustomValueType | (string & {}) | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | (string & {}) | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        overscrollBehaviorBlock?: import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        overscrollBehaviorInline?: import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        overscrollBehaviorX?: import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        overscrollBehaviorY?: import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "contain" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        paddingBlock?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        paddingBlockEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        paddingBlockStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        paddingBottom?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        paddingInline?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        paddingInlineEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        paddingInlineStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        paddingLeft?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        paddingRight?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        paddingTop?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        pageBreakAfter?: import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "recto" | "verso" | (import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "recto" | "verso" | undefined)[] | [null, ...(import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "recto" | "verso" | undefined)[]] | undefined;
        pageBreakBefore?: import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "recto" | "verso" | (import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "recto" | "verso" | undefined)[] | [null, ...(import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "always" | "avoid" | "recto" | "verso" | undefined)[]] | undefined;
        pageBreakInside?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "avoid" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "avoid" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "avoid" | undefined)[]] | undefined;
        paintOrder?: import("../../types").CustomValueType | (string & {}) | "fill" | "stroke" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "markers" | (import("../../types").CustomValueType | (string & {}) | "fill" | "stroke" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "markers" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "fill" | "stroke" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "markers" | undefined)[]] | undefined;
        perspectiveOrigin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        placeContent?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | undefined)[]] | undefined;
        pointerEvents?: import("../../types").CustomValueType | "all" | "fill" | "stroke" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "painted" | "visible" | "visibleFill" | "visiblePainted" | "visibleStroke" | (import("../../types").CustomValueType | "all" | "fill" | "stroke" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "painted" | "visible" | "visibleFill" | "visiblePainted" | "visibleStroke" | undefined)[] | [null, ...(import("../../types").CustomValueType | "all" | "fill" | "stroke" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "painted" | "visible" | "visibleFill" | "visiblePainted" | "visibleStroke" | undefined)[]] | undefined;
        position?: import("../../types").CustomValueType | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "-webkit-sticky" | "absolute" | "relative" | "static" | "sticky" | (import("../../types").CustomValueType | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "-webkit-sticky" | "absolute" | "relative" | "static" | "sticky" | undefined)[] | [null, ...(import("../../types").CustomValueType | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "-webkit-sticky" | "absolute" | "relative" | "static" | "sticky" | undefined)[]] | undefined;
        quotes?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        resize?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "both" | "horizontal" | "vertical" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "both" | "horizontal" | "vertical" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "both" | "horizontal" | "vertical" | undefined)[]] | undefined;
        right?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        rowGap?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        rubyAlign?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "start" | "space-around" | "space-between" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "start" | "space-around" | "space-between" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "start" | "space-around" | "space-between" | undefined)[]] | undefined;
        rubyMerge?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "collapse" | "separate" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "collapse" | "separate" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "collapse" | "separate" | undefined)[]] | undefined;
        rubyPosition?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "over" | "under" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "over" | "under" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "over" | "under" | undefined)[]] | undefined;
        scrollBehavior?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "smooth" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "smooth" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "smooth" | undefined)[]] | undefined;
        scrollMargin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollMarginBlock?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollMarginBlockEnd?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollMarginBlockStart?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollMarginBottom?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollMarginInline?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollMarginInlineEnd?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollMarginInlineStart?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollMarginLeft?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollMarginRight?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollMarginTop?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollPadding?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollPaddingBlock?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollPaddingBlockEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollPaddingBlockStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollPaddingBottom?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollPaddingInline?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollPaddingInlineEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollPaddingInlineStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollPaddingLeft?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollPaddingRight?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollPaddingTop?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollSnapAlign?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "center" | "end" | "start" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "center" | "end" | "start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "center" | "end" | "start" | undefined)[]] | undefined;
        scrollSnapMargin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollSnapMarginBottom?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollSnapMarginLeft?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollSnapMarginRight?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollSnapMarginTop?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scrollSnapStop?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "always" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "always" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "always" | undefined)[]] | undefined;
        scrollSnapType?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "x" | "y" | "both" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "x" | "y" | "both" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "x" | "y" | "both" | undefined)[]] | undefined;
        scrollbarColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "auto" | "dark" | "light" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "auto" | "dark" | "light" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "auto" | "dark" | "light" | undefined)[]] | undefined;
        scrollbarWidth?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "thin" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "thin" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "thin" | undefined)[]] | undefined;
        shapeImageThreshold?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        shapeMargin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        shapeOutside?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "margin-box" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "margin-box" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "margin-box" | "none" | undefined)[]] | undefined;
        tabSize?: string | number | import("../../types").CustomValueType | (number & {}) | (string | number | import("../../types").CustomValueType | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (number & {}) | undefined)[]] | undefined;
        tableLayout?: import("../../types").CustomValueType | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (import("../../types").CustomValueType | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[]] | undefined;
        textAlign?: import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | "match-parent" | (import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | "match-parent" | undefined)[] | [null, ...(import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | "match-parent" | undefined)[]] | undefined;
        textAlignLast?: import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "center" | "end" | "start" | "justify" | (import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "center" | "end" | "start" | "justify" | undefined)[] | [null, ...(import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "center" | "end" | "start" | "justify" | undefined)[]] | undefined;
        textCombineUpright?: import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | (import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | undefined)[]] | undefined;
        textDecorationColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        textDecorationLine?: import("../../types").CustomValueType | (string & {}) | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grammar-error" | "line-through" | "overline" | "spelling-error" | "underline" | (import("../../types").CustomValueType | (string & {}) | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grammar-error" | "line-through" | "overline" | "spelling-error" | "underline" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grammar-error" | "line-through" | "overline" | "spelling-error" | "underline" | undefined)[]] | undefined;
        textDecorationSkip?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "box-decoration" | "edges" | "leading-spaces" | "objects" | "spaces" | "trailing-spaces" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "box-decoration" | "edges" | "leading-spaces" | "objects" | "spaces" | "trailing-spaces" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "box-decoration" | "edges" | "leading-spaces" | "objects" | "spaces" | "trailing-spaces" | undefined)[]] | undefined;
        textDecorationSkipInk?: import("../../types").CustomValueType | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        textDecorationStyle?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "dashed" | "dotted" | "double" | "solid" | "wavy" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "dashed" | "dotted" | "double" | "solid" | "wavy" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "dashed" | "dotted" | "double" | "solid" | "wavy" | undefined)[]] | undefined;
        textDecorationThickness?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        textDecorationWidth?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        textEmphasisColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        textEmphasisPosition?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        textEmphasisStyle?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | undefined)[]] | undefined;
        textIndent?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        textJustify?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "inter-character" | "inter-word" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "inter-character" | "inter-word" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "inter-character" | "inter-word" | undefined)[]] | undefined;
        textOrientation?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "mixed" | "sideways" | "upright" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "mixed" | "sideways" | "upright" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "mixed" | "sideways" | "upright" | undefined)[]] | undefined;
        textOverflow?: import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | (import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | undefined)[]] | undefined;
        textRendering?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "geometricPrecision" | "optimizeLegibility" | "optimizeSpeed" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "geometricPrecision" | "optimizeLegibility" | "optimizeSpeed" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "geometricPrecision" | "optimizeLegibility" | "optimizeSpeed" | undefined)[]] | undefined;
        textShadow?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        textSizeAdjust?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        textTransform?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "full-width" | "capitalize" | "full-size-kana" | "lowercase" | "uppercase" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "full-width" | "capitalize" | "full-size-kana" | "lowercase" | "uppercase" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "full-width" | "capitalize" | "full-size-kana" | "lowercase" | "uppercase" | undefined)[]] | undefined;
        textUnderlineOffset?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        textUnderlinePosition?: import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "from-font" | "under" | (import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "from-font" | "under" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "from-font" | "under" | undefined)[]] | undefined;
        top?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        touchAction?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "-ms-manipulation" | "-ms-none" | "-ms-pinch-zoom" | "manipulation" | "pan-down" | "pan-left" | "pan-right" | "pan-up" | "pan-x" | "pan-y" | "pinch-zoom" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "-ms-manipulation" | "-ms-none" | "-ms-pinch-zoom" | "manipulation" | "pan-down" | "pan-left" | "pan-right" | "pan-up" | "pan-x" | "pan-y" | "pinch-zoom" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "-ms-manipulation" | "-ms-none" | "-ms-pinch-zoom" | "manipulation" | "pan-down" | "pan-left" | "pan-right" | "pan-up" | "pan-x" | "pan-y" | "pinch-zoom" | undefined)[]] | undefined;
        transform?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        transformBox?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "fill-box" | "stroke-box" | "view-box" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "fill-box" | "stroke-box" | "view-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "fill-box" | "stroke-box" | "view-box" | undefined)[]] | undefined;
        transformOrigin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        transformStyle?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flat" | "preserve-3d" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flat" | "preserve-3d" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flat" | "preserve-3d" | undefined)[]] | undefined;
        transitionDelay?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        transitionDuration?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        transitionProperty?: import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        transitionTimingFunction?: import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        translate?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        unicodeBidi?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "-moz-isolate" | "-moz-isolate-override" | "-moz-plaintext" | "-webkit-isolate" | "bidi-override" | "embed" | "isolate" | "isolate-override" | "plaintext" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "-moz-isolate" | "-moz-isolate-override" | "-moz-plaintext" | "-webkit-isolate" | "bidi-override" | "embed" | "isolate" | "isolate-override" | "plaintext" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "-moz-isolate" | "-moz-isolate-override" | "-moz-plaintext" | "-webkit-isolate" | "bidi-override" | "embed" | "isolate" | "isolate-override" | "plaintext" | undefined)[]] | undefined;
        userSelect?: import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | (import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | undefined)[] | [null, ...(import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | undefined)[]] | undefined;
        verticalAlign?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        visibility?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "collapse" | "hidden" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "collapse" | "hidden" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "collapse" | "hidden" | undefined)[]] | undefined;
        whiteSpace?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "pre" | "nowrap" | "-moz-pre-wrap" | "break-spaces" | "pre-line" | "pre-wrap" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "pre" | "nowrap" | "-moz-pre-wrap" | "break-spaces" | "pre-line" | "pre-wrap" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "pre" | "nowrap" | "-moz-pre-wrap" | "break-spaces" | "pre-line" | "pre-wrap" | undefined)[]] | undefined;
        widows?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        width?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        willChange?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "contents" | "scroll-position" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "contents" | "scroll-position" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "contents" | "scroll-position" | undefined)[]] | undefined;
        wordBreak?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "break-word" | "break-all" | "keep-all" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "break-word" | "break-all" | "keep-all" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "break-word" | "break-all" | "keep-all" | undefined)[]] | undefined;
        wordSpacing?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        wordWrap?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "break-word" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "break-word" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "break-word" | undefined)[]] | undefined;
        writingMode?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal-tb" | "sideways-lr" | "sideways-rl" | "vertical-lr" | "vertical-rl" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal-tb" | "sideways-lr" | "sideways-rl" | "vertical-lr" | "vertical-rl" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal-tb" | "sideways-lr" | "sideways-rl" | "vertical-lr" | "vertical-rl" | undefined)[]] | undefined;
        zIndex?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        zoom?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "normal" | "reset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "normal" | "reset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "normal" | "reset" | undefined)[]] | undefined;
        all?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        animation?: import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        background?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        border?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderBlock?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderBlockEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderBlockStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderBottom?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        borderImage?: import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | (import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | undefined)[]] | undefined;
        borderInline?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderInlineEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderInlineStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderLeft?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderRight?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderStyle?: import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        borderTop?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        borderWidth?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        columnRule?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        columns?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        flex?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        flexFlow?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | "nowrap" | "wrap" | "wrap-reverse" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | "nowrap" | "wrap" | "wrap-reverse" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | "nowrap" | "wrap" | "wrap-reverse" | undefined)[]] | undefined;
        font?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "caption" | "menu" | "icon" | "message-box" | "small-caption" | "status-bar" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "caption" | "menu" | "icon" | "message-box" | "small-caption" | "status-bar" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "caption" | "menu" | "icon" | "message-box" | "small-caption" | "status-bar" | undefined)[]] | undefined;
        gap?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        grid?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        gridArea?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        gridColumn?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        gridRow?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        gridTemplate?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        lineClamp?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | undefined)[]] | undefined;
        listStyle?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "inside" | "outside" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "inside" | "outside" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "inside" | "outside" | undefined)[]] | undefined;
        margin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        mask?: string | import("../../types").CustomValueType | (string & {}) | (string | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        maskBorder?: import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "alpha" | "luminance" | "stretch" | (import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "alpha" | "luminance" | "stretch" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "alpha" | "luminance" | "stretch" | undefined)[]] | undefined;
        motion?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        offset?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        outline?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        overflow?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[]] | undefined;
        padding?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        placeItems?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[]] | undefined;
        placeSelf?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[]] | undefined;
        textDecoration?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        textEmphasis?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | undefined)[]] | undefined;
        MozAnimationDelay?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        MozAnimationDirection?: import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | (import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | undefined)[]] | undefined;
        MozAnimationDuration?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        MozAnimationFillMode?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | undefined)[]] | undefined;
        MozAnimationIterationCount?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | undefined)[]] | undefined;
        MozAnimationName?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        MozAnimationPlayState?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | undefined)[]] | undefined;
        MozAnimationTimingFunction?: import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        MozAppearance?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "button" | "menuitem" | "checkbox" | "listbox" | "menulist" | "radio" | "searchfield" | "menulist-button" | "textfield" | "-moz-mac-unified-toolbar" | "-moz-win-borderless-glass" | "-moz-win-browsertabbar-toolbox" | "-moz-win-communications-toolbox" | "-moz-win-communicationstext" | "-moz-win-exclude-glass" | "-moz-win-glass" | "-moz-win-media-toolbox" | "-moz-win-mediatext" | "-moz-window-button-box" | "-moz-window-button-box-maximized" | "-moz-window-button-close" | "-moz-window-button-maximize" | "-moz-window-button-minimize" | "-moz-window-button-restore" | "-moz-window-frame-bottom" | "-moz-window-frame-left" | "-moz-window-frame-right" | "-moz-window-titlebar" | "-moz-window-titlebar-maximized" | "button-arrow-down" | "button-arrow-next" | "button-arrow-previous" | "button-arrow-up" | "button-bevel" | "button-focus" | "caret" | "checkbox-container" | "checkbox-label" | "checkmenuitem" | "dualbutton" | "groupbox" | "listitem" | "menuarrow" | "menubar" | "menucheckbox" | "menuimage" | "menuitemtext" | "menulist-text" | "menulist-textfield" | "menupopup" | "menuradio" | "menuseparator" | "meterbar" | "meterchunk" | "progressbar" | "progressbar-vertical" | "progresschunk" | "progresschunk-vertical" | "radio-container" | "radio-label" | "radiomenuitem" | "range" | "range-thumb" | "resizer" | "resizerpanel" | "scale-horizontal" | "scale-vertical" | "scalethumb-horizontal" | "scalethumb-vertical" | "scalethumbend" | "scalethumbstart" | "scalethumbtick" | "scrollbarbutton-down" | "scrollbarbutton-left" | "scrollbarbutton-right" | "scrollbarbutton-up" | "scrollbarthumb-horizontal" | "scrollbarthumb-vertical" | "scrollbartrack-horizontal" | "scrollbartrack-vertical" | "separator" | "sheet" | "spinner" | "spinner-downbutton" | "spinner-textfield" | "spinner-upbutton" | "splitter" | "statusbar" | "statusbarpanel" | "tab" | "tab-scroll-arrow-back" | "tab-scroll-arrow-forward" | "tabpanel" | "tabpanels" | "textfield-multiline" | "toolbar" | "toolbarbutton" | "toolbarbutton-dropdown" | "toolbargripper" | "toolbox" | "tooltip" | "treeheader" | "treeheadercell" | "treeheadersortarrow" | "treeitem" | "treeline" | "treetwisty" | "treetwistyopen" | "treeview" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "button" | "menuitem" | "checkbox" | "listbox" | "menulist" | "radio" | "searchfield" | "menulist-button" | "textfield" | "-moz-mac-unified-toolbar" | "-moz-win-borderless-glass" | "-moz-win-browsertabbar-toolbox" | "-moz-win-communications-toolbox" | "-moz-win-communicationstext" | "-moz-win-exclude-glass" | "-moz-win-glass" | "-moz-win-media-toolbox" | "-moz-win-mediatext" | "-moz-window-button-box" | "-moz-window-button-box-maximized" | "-moz-window-button-close" | "-moz-window-button-maximize" | "-moz-window-button-minimize" | "-moz-window-button-restore" | "-moz-window-frame-bottom" | "-moz-window-frame-left" | "-moz-window-frame-right" | "-moz-window-titlebar" | "-moz-window-titlebar-maximized" | "button-arrow-down" | "button-arrow-next" | "button-arrow-previous" | "button-arrow-up" | "button-bevel" | "button-focus" | "caret" | "checkbox-container" | "checkbox-label" | "checkmenuitem" | "dualbutton" | "groupbox" | "listitem" | "menuarrow" | "menubar" | "menucheckbox" | "menuimage" | "menuitemtext" | "menulist-text" | "menulist-textfield" | "menupopup" | "menuradio" | "menuseparator" | "meterbar" | "meterchunk" | "progressbar" | "progressbar-vertical" | "progresschunk" | "progresschunk-vertical" | "radio-container" | "radio-label" | "radiomenuitem" | "range" | "range-thumb" | "resizer" | "resizerpanel" | "scale-horizontal" | "scale-vertical" | "scalethumb-horizontal" | "scalethumb-vertical" | "scalethumbend" | "scalethumbstart" | "scalethumbtick" | "scrollbarbutton-down" | "scrollbarbutton-left" | "scrollbarbutton-right" | "scrollbarbutton-up" | "scrollbarthumb-horizontal" | "scrollbarthumb-vertical" | "scrollbartrack-horizontal" | "scrollbartrack-vertical" | "separator" | "sheet" | "spinner" | "spinner-downbutton" | "spinner-textfield" | "spinner-upbutton" | "splitter" | "statusbar" | "statusbarpanel" | "tab" | "tab-scroll-arrow-back" | "tab-scroll-arrow-forward" | "tabpanel" | "tabpanels" | "textfield-multiline" | "toolbar" | "toolbarbutton" | "toolbarbutton-dropdown" | "toolbargripper" | "toolbox" | "tooltip" | "treeheader" | "treeheadercell" | "treeheadersortarrow" | "treeitem" | "treeline" | "treetwisty" | "treetwistyopen" | "treeview" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "button" | "menuitem" | "checkbox" | "listbox" | "menulist" | "radio" | "searchfield" | "menulist-button" | "textfield" | "-moz-mac-unified-toolbar" | "-moz-win-borderless-glass" | "-moz-win-browsertabbar-toolbox" | "-moz-win-communications-toolbox" | "-moz-win-communicationstext" | "-moz-win-exclude-glass" | "-moz-win-glass" | "-moz-win-media-toolbox" | "-moz-win-mediatext" | "-moz-window-button-box" | "-moz-window-button-box-maximized" | "-moz-window-button-close" | "-moz-window-button-maximize" | "-moz-window-button-minimize" | "-moz-window-button-restore" | "-moz-window-frame-bottom" | "-moz-window-frame-left" | "-moz-window-frame-right" | "-moz-window-titlebar" | "-moz-window-titlebar-maximized" | "button-arrow-down" | "button-arrow-next" | "button-arrow-previous" | "button-arrow-up" | "button-bevel" | "button-focus" | "caret" | "checkbox-container" | "checkbox-label" | "checkmenuitem" | "dualbutton" | "groupbox" | "listitem" | "menuarrow" | "menubar" | "menucheckbox" | "menuimage" | "menuitemtext" | "menulist-text" | "menulist-textfield" | "menupopup" | "menuradio" | "menuseparator" | "meterbar" | "meterchunk" | "progressbar" | "progressbar-vertical" | "progresschunk" | "progresschunk-vertical" | "radio-container" | "radio-label" | "radiomenuitem" | "range" | "range-thumb" | "resizer" | "resizerpanel" | "scale-horizontal" | "scale-vertical" | "scalethumb-horizontal" | "scalethumb-vertical" | "scalethumbend" | "scalethumbstart" | "scalethumbtick" | "scrollbarbutton-down" | "scrollbarbutton-left" | "scrollbarbutton-right" | "scrollbarbutton-up" | "scrollbarthumb-horizontal" | "scrollbarthumb-vertical" | "scrollbartrack-horizontal" | "scrollbartrack-vertical" | "separator" | "sheet" | "spinner" | "spinner-downbutton" | "spinner-textfield" | "spinner-upbutton" | "splitter" | "statusbar" | "statusbarpanel" | "tab" | "tab-scroll-arrow-back" | "tab-scroll-arrow-forward" | "tabpanel" | "tabpanels" | "textfield-multiline" | "toolbar" | "toolbarbutton" | "toolbarbutton-dropdown" | "toolbargripper" | "toolbox" | "tooltip" | "treeheader" | "treeheadercell" | "treeheadersortarrow" | "treeitem" | "treeline" | "treetwisty" | "treetwistyopen" | "treeview" | undefined)[]] | undefined;
        MozBackfaceVisibility?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "hidden" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "hidden" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "hidden" | undefined)[]] | undefined;
        MozBorderBottomColors?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        MozBorderEndColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        MozBorderEndStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        MozBorderEndWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        MozBorderLeftColors?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        MozBorderRightColors?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        MozBorderStartColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        MozBorderStartStyle?: import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        MozBorderTopColors?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        MozBoxSizing?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | undefined)[]] | undefined;
        MozColumnCount?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        MozColumnFill?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "balance" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "balance" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "balance" | undefined)[]] | undefined;
        MozColumnGap?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozColumnRuleColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        MozColumnRuleStyle?: import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        MozColumnRuleWidth?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozColumnWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        MozContextProperties?: import("../../types").CustomValueType | (string & {}) | "fill" | "stroke" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "fill-opacity" | "stroke-opacity" | (import("../../types").CustomValueType | (string & {}) | "fill" | "stroke" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "fill-opacity" | "stroke-opacity" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "fill" | "stroke" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "fill-opacity" | "stroke-opacity" | undefined)[]] | undefined;
        MozFontFeatureSettings?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[]] | undefined;
        MozFontLanguageOverride?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[]] | undefined;
        MozHyphens?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | undefined)[]] | undefined;
        MozImageRegion?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[]] | undefined;
        MozMarginEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozMarginStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozOrient?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "block" | "inline" | "horizontal" | "vertical" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "block" | "inline" | "horizontal" | "vertical" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "block" | "inline" | "horizontal" | "vertical" | undefined)[]] | undefined;
        MozOsxFontSmoothing?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        MozPaddingEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozPaddingStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozPerspective?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        MozPerspectiveOrigin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozStackSizing?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ignore" | "stretch-to-fit" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ignore" | "stretch-to-fit" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ignore" | "stretch-to-fit" | undefined)[]] | undefined;
        MozTabSize?: string | number | import("../../types").CustomValueType | (number & {}) | (string | number | import("../../types").CustomValueType | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (number & {}) | undefined)[]] | undefined;
        MozTextBlink?: import("../../types").CustomValueType | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        MozTextSizeAdjust?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        MozTransformOrigin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozTransformStyle?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flat" | "preserve-3d" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flat" | "preserve-3d" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flat" | "preserve-3d" | undefined)[]] | undefined;
        MozTransitionDelay?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        MozTransitionDuration?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        MozTransitionProperty?: import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        MozTransitionTimingFunction?: import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        MozUserFocus?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "normal" | "ignore" | "select-after" | "select-all" | "select-before" | "select-menu" | "select-same" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "normal" | "ignore" | "select-after" | "select-all" | "select-before" | "select-menu" | "select-same" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "normal" | "ignore" | "select-after" | "select-all" | "select-before" | "select-menu" | "select-same" | undefined)[]] | undefined;
        MozUserModify?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "read-only" | "read-write" | "write-only" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "read-only" | "read-write" | "write-only" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "read-only" | "read-write" | "write-only" | undefined)[]] | undefined;
        MozUserSelect?: import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | (import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | undefined)[] | [null, ...(import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | undefined)[]] | undefined;
        MozWindowDragging?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "drag" | "no-drag" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "drag" | "no-drag" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "drag" | "no-drag" | undefined)[]] | undefined;
        MozWindowShadow?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "default" | "menu" | "sheet" | "tooltip" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "default" | "menu" | "sheet" | "tooltip" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "default" | "menu" | "sheet" | "tooltip" | undefined)[]] | undefined;
        msAccelerator?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "true" | "false" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "true" | "false" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "true" | "false" | undefined)[]] | undefined;
        msAlignSelf?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[]] | undefined;
        msBlockProgression?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "bt" | "lr" | "rl" | "tb" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "bt" | "lr" | "rl" | "tb" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "bt" | "lr" | "rl" | "tb" | undefined)[]] | undefined;
        msContentZoomChaining?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "chained" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "chained" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "chained" | undefined)[]] | undefined;
        msContentZoomLimitMax?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msContentZoomLimitMin?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msContentZoomSnapPoints?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msContentZoomSnapType?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | undefined)[]] | undefined;
        msContentZooming?: import("../../types").CustomValueType | "zoom" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | "zoom" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | "zoom" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        msFilter?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msFlexDirection?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | undefined)[]] | undefined;
        msFlexPositive?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        msFlowFrom?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        msFlowInto?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        msGridColumns?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        msGridRows?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        msHighContrastAdjust?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        msHyphenateLimitChars?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        msHyphenateLimitLines?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "no-limit" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "no-limit" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "no-limit" | undefined)[]] | undefined;
        msHyphenateLimitZone?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        msHyphens?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | undefined)[]] | undefined;
        msImeAlign?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "after" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "after" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "after" | undefined)[]] | undefined;
        msLineBreak?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | undefined)[]] | undefined;
        msOrder?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        msOverflowStyle?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "-ms-autohiding-scrollbar" | "scrollbar" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "-ms-autohiding-scrollbar" | "scrollbar" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "-ms-autohiding-scrollbar" | "scrollbar" | undefined)[]] | undefined;
        msOverflowX?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[]] | undefined;
        msOverflowY?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "visible" | "hidden" | "scroll" | undefined)[]] | undefined;
        msScrollChaining?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "chained" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "chained" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "chained" | undefined)[]] | undefined;
        msScrollLimitXMax?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        msScrollLimitXMin?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        msScrollLimitYMax?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        msScrollLimitYMin?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        msScrollRails?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "railed" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "railed" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "railed" | undefined)[]] | undefined;
        msScrollSnapPointsX?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msScrollSnapPointsY?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msScrollSnapType?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | undefined)[]] | undefined;
        msScrollTranslation?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "vertical-to-horizontal" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "vertical-to-horizontal" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "vertical-to-horizontal" | undefined)[]] | undefined;
        msScrollbar3dlightColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        msScrollbarArrowColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        msScrollbarBaseColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        msScrollbarDarkshadowColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        msScrollbarFaceColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        msScrollbarHighlightColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        msScrollbarShadowColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        msTextAutospace?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ideograph-alpha" | "ideograph-numeric" | "ideograph-parenthesis" | "ideograph-space" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ideograph-alpha" | "ideograph-numeric" | "ideograph-parenthesis" | "ideograph-space" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ideograph-alpha" | "ideograph-numeric" | "ideograph-parenthesis" | "ideograph-space" | undefined)[]] | undefined;
        msTextCombineHorizontal?: import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | (import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | undefined)[]] | undefined;
        msTextOverflow?: import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | (import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | undefined)[]] | undefined;
        msTouchAction?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "-ms-manipulation" | "-ms-none" | "-ms-pinch-zoom" | "manipulation" | "pan-down" | "pan-left" | "pan-right" | "pan-up" | "pan-x" | "pan-y" | "pinch-zoom" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "-ms-manipulation" | "-ms-none" | "-ms-pinch-zoom" | "manipulation" | "pan-down" | "pan-left" | "pan-right" | "pan-up" | "pan-x" | "pan-y" | "pinch-zoom" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "-ms-manipulation" | "-ms-none" | "-ms-pinch-zoom" | "manipulation" | "pan-down" | "pan-left" | "pan-right" | "pan-up" | "pan-x" | "pan-y" | "pinch-zoom" | undefined)[]] | undefined;
        msTouchSelect?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grippers" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grippers" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grippers" | undefined)[]] | undefined;
        msTransform?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        msTransformOrigin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        msTransitionDelay?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msTransitionDuration?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msTransitionProperty?: import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        msTransitionTimingFunction?: import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        msUserSelect?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "text" | "element" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "text" | "element" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "text" | "element" | undefined)[]] | undefined;
        msWordBreak?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "break-word" | "break-all" | "keep-all" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "break-word" | "break-all" | "keep-all" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "break-word" | "break-all" | "keep-all" | undefined)[]] | undefined;
        msWrapFlow?: import("../../types").CustomValueType | "clear" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "end" | "start" | "both" | "maximum" | (import("../../types").CustomValueType | "clear" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "end" | "start" | "both" | "maximum" | undefined)[] | [null, ...(import("../../types").CustomValueType | "clear" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "end" | "start" | "both" | "maximum" | undefined)[]] | undefined;
        msWrapMargin?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        msWrapThrough?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "wrap" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "wrap" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "wrap" | undefined)[]] | undefined;
        msWritingMode?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal-tb" | "sideways-lr" | "sideways-rl" | "vertical-lr" | "vertical-rl" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal-tb" | "sideways-lr" | "sideways-rl" | "vertical-lr" | "vertical-rl" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal-tb" | "sideways-lr" | "sideways-rl" | "vertical-lr" | "vertical-rl" | undefined)[]] | undefined;
        OObjectFit?: import("../../types").CustomValueType | "contain" | "fill" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "cover" | "scale-down" | (import("../../types").CustomValueType | "contain" | "fill" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "cover" | "scale-down" | undefined)[] | [null, ...(import("../../types").CustomValueType | "contain" | "fill" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "cover" | "scale-down" | undefined)[]] | undefined;
        OObjectPosition?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        OTabSize?: string | number | import("../../types").CustomValueType | (number & {}) | (string | number | import("../../types").CustomValueType | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (number & {}) | undefined)[]] | undefined;
        OTextOverflow?: import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | (import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "clip" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ellipsis" | undefined)[]] | undefined;
        OTransformOrigin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitAlignContent?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | undefined)[]] | undefined;
        WebkitAlignItems?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[]] | undefined;
        WebkitAlignSelf?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "center" | "baseline" | "end" | "start" | "stretch" | "flex-end" | "flex-start" | "self-end" | "self-start" | undefined)[]] | undefined;
        WebkitAnimationDelay?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        WebkitAnimationDirection?: import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | (import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | undefined)[]] | undefined;
        WebkitAnimationDuration?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        WebkitAnimationFillMode?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | undefined)[]] | undefined;
        WebkitAnimationIterationCount?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | undefined)[]] | undefined;
        WebkitAnimationName?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        WebkitAnimationPlayState?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | undefined)[]] | undefined;
        WebkitAnimationTimingFunction?: import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        WebkitAppearance?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "button" | "meter" | "textarea" | "checkbox" | "listbox" | "menulist" | "progress-bar" | "push-button" | "radio" | "searchfield" | "slider-horizontal" | "square-button" | "menulist-button" | "textfield" | "button-bevel" | "caret" | "listitem" | "menulist-text" | "menulist-textfield" | "default-button" | "inner-spin-button" | "media-controls-background" | "media-controls-fullscreen-background" | "media-current-time-display" | "media-enter-fullscreen-button" | "media-exit-fullscreen-button" | "media-fullscreen-button" | "media-mute-button" | "media-overlay-play-button" | "media-play-button" | "media-seek-back-button" | "media-seek-forward-button" | "media-slider" | "media-sliderthumb" | "media-time-remaining-display" | "media-toggle-closed-captions-button" | "media-volume-slider" | "media-volume-slider-container" | "media-volume-sliderthumb" | "progress-bar-value" | "searchfield-cancel-button" | "searchfield-decoration" | "searchfield-results-button" | "searchfield-results-decoration" | "slider-vertical" | "sliderthumb-horizontal" | "sliderthumb-vertical" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "button" | "meter" | "textarea" | "checkbox" | "listbox" | "menulist" | "progress-bar" | "push-button" | "radio" | "searchfield" | "slider-horizontal" | "square-button" | "menulist-button" | "textfield" | "button-bevel" | "caret" | "listitem" | "menulist-text" | "menulist-textfield" | "default-button" | "inner-spin-button" | "media-controls-background" | "media-controls-fullscreen-background" | "media-current-time-display" | "media-enter-fullscreen-button" | "media-exit-fullscreen-button" | "media-fullscreen-button" | "media-mute-button" | "media-overlay-play-button" | "media-play-button" | "media-seek-back-button" | "media-seek-forward-button" | "media-slider" | "media-sliderthumb" | "media-time-remaining-display" | "media-toggle-closed-captions-button" | "media-volume-slider" | "media-volume-slider-container" | "media-volume-sliderthumb" | "progress-bar-value" | "searchfield-cancel-button" | "searchfield-decoration" | "searchfield-results-button" | "searchfield-results-decoration" | "slider-vertical" | "sliderthumb-horizontal" | "sliderthumb-vertical" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "button" | "meter" | "textarea" | "checkbox" | "listbox" | "menulist" | "progress-bar" | "push-button" | "radio" | "searchfield" | "slider-horizontal" | "square-button" | "menulist-button" | "textfield" | "button-bevel" | "caret" | "listitem" | "menulist-text" | "menulist-textfield" | "default-button" | "inner-spin-button" | "media-controls-background" | "media-controls-fullscreen-background" | "media-current-time-display" | "media-enter-fullscreen-button" | "media-exit-fullscreen-button" | "media-fullscreen-button" | "media-mute-button" | "media-overlay-play-button" | "media-play-button" | "media-seek-back-button" | "media-seek-forward-button" | "media-slider" | "media-sliderthumb" | "media-time-remaining-display" | "media-toggle-closed-captions-button" | "media-volume-slider" | "media-volume-slider-container" | "media-volume-sliderthumb" | "progress-bar-value" | "searchfield-cancel-button" | "searchfield-decoration" | "searchfield-results-button" | "searchfield-results-decoration" | "slider-vertical" | "sliderthumb-horizontal" | "sliderthumb-vertical" | undefined)[]] | undefined;
        WebkitBackdropFilter?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        WebkitBackfaceVisibility?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "hidden" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "hidden" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "visible" | "hidden" | undefined)[]] | undefined;
        WebkitBackgroundClip?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[]] | undefined;
        WebkitBackgroundOrigin?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[]] | undefined;
        WebkitBackgroundSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitBorderBeforeColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        WebkitBorderBeforeStyle?: import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        WebkitBorderBeforeWidth?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitBorderBottomLeftRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitBorderBottomRightRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitBorderImageSlice?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        WebkitBorderTopLeftRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitBorderTopRightRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitBoxDecorationBreak?: import("../../types").CustomValueType | "slice" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "clone" | (import("../../types").CustomValueType | "slice" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "clone" | undefined)[] | [null, ...(import("../../types").CustomValueType | "slice" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "clone" | undefined)[]] | undefined;
        WebkitBoxReflect?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitBoxShadow?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        WebkitBoxSizing?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | undefined)[]] | undefined;
        WebkitClipPath?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "fill-box" | "margin-box" | "stroke-box" | "view-box" | "none" | undefined)[]] | undefined;
        WebkitColumnCount?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        WebkitColumnFill?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "balance" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "balance" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "balance" | undefined)[]] | undefined;
        WebkitColumnGap?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitColumnRuleColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        WebkitColumnRuleStyle?: import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        WebkitColumnRuleWidth?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitColumnSpan?: import("../../types").CustomValueType | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        WebkitColumnWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        WebkitFilter?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        WebkitFlexBasis?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitFlexDirection?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | undefined)[]] | undefined;
        WebkitFlexGrow?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        WebkitFlexShrink?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        WebkitFlexWrap?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "nowrap" | "wrap" | "wrap-reverse" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "nowrap" | "wrap" | "wrap-reverse" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "nowrap" | "wrap" | "wrap-reverse" | undefined)[]] | undefined;
        WebkitFontFeatureSettings?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[]] | undefined;
        WebkitFontKerning?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "normal" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "normal" | undefined)[]] | undefined;
        WebkitFontSmoothing?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        WebkitFontVariantLigatures?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "normal" | "common-ligatures" | "contextual" | "discretionary-ligatures" | "historical-ligatures" | "no-common-ligatures" | "no-contextual" | "no-discretionary-ligatures" | "no-historical-ligatures" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "normal" | "common-ligatures" | "contextual" | "discretionary-ligatures" | "historical-ligatures" | "no-common-ligatures" | "no-contextual" | "no-discretionary-ligatures" | "no-historical-ligatures" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "normal" | "common-ligatures" | "contextual" | "discretionary-ligatures" | "historical-ligatures" | "no-common-ligatures" | "no-contextual" | "no-discretionary-ligatures" | "no-historical-ligatures" | undefined)[]] | undefined;
        WebkitHyphens?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "manual" | undefined)[]] | undefined;
        WebkitJustifyContent?: import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | (import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "center" | "end" | "start" | "space-around" | "space-between" | "space-evenly" | "stretch" | "flex-end" | "flex-start" | undefined)[]] | undefined;
        WebkitLineBreak?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | undefined)[]] | undefined;
        WebkitLineClamp?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | undefined)[]] | undefined;
        WebkitMarginEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitMarginStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitMaskAttachment?: import("../../types").CustomValueType | (string & {}) | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "scroll" | "local" | (import("../../types").CustomValueType | (string & {}) | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "scroll" | "local" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "fixed" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "scroll" | "local" | undefined)[]] | undefined;
        WebkitMaskClip?: import("../../types").CustomValueType | (string & {}) | "content" | "border" | "padding" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "text" | (import("../../types").CustomValueType | (string & {}) | "content" | "border" | "padding" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "text" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "content" | "border" | "padding" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "text" | undefined)[]] | undefined;
        WebkitMaskComposite?: import("../../types").CustomValueType | (string & {}) | "clear" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "copy" | "destination-atop" | "destination-in" | "destination-out" | "destination-over" | "source-atop" | "source-in" | "source-out" | "source-over" | "xor" | (import("../../types").CustomValueType | (string & {}) | "clear" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "copy" | "destination-atop" | "destination-in" | "destination-out" | "destination-over" | "source-atop" | "source-in" | "source-out" | "source-over" | "xor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "clear" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "copy" | "destination-atop" | "destination-in" | "destination-out" | "destination-over" | "source-atop" | "source-in" | "source-out" | "source-over" | "xor" | undefined)[]] | undefined;
        WebkitMaskImage?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        WebkitMaskOrigin?: import("../../types").CustomValueType | (string & {}) | "content" | "border" | "padding" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | (import("../../types").CustomValueType | (string & {}) | "content" | "border" | "padding" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "content" | "border" | "padding" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[]] | undefined;
        WebkitMaskPosition?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitMaskPositionX?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitMaskPositionY?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitMaskRepeat?: import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "repeat-x" | "repeat-y" | "round" | "space" | (import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "repeat-x" | "repeat-y" | "round" | "space" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "repeat-x" | "repeat-y" | "round" | "space" | undefined)[]] | undefined;
        WebkitMaskRepeatX?: import("../../types").CustomValueType | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "round" | "space" | (import("../../types").CustomValueType | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "round" | "space" | undefined)[] | [null, ...(import("../../types").CustomValueType | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "round" | "space" | undefined)[]] | undefined;
        WebkitMaskRepeatY?: import("../../types").CustomValueType | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "round" | "space" | (import("../../types").CustomValueType | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "round" | "space" | undefined)[] | [null, ...(import("../../types").CustomValueType | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "no-repeat" | "round" | "space" | undefined)[]] | undefined;
        WebkitMaskSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitMaxInlineSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitOrder?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        WebkitOverflowScrolling?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "touch" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "touch" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "touch" | undefined)[]] | undefined;
        WebkitPaddingEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitPaddingStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitPerspective?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        WebkitPerspectiveOrigin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitPrintColorAdjust?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "economy" | "exact" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "economy" | "exact" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "economy" | "exact" | undefined)[]] | undefined;
        WebkitScrollSnapType?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "x" | "y" | "both" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "x" | "y" | "both" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "block" | "inline" | "x" | "y" | "both" | undefined)[]] | undefined;
        WebkitShapeMargin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitTapHighlightColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        WebkitTextCombine?: import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | (import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | undefined)[]] | undefined;
        WebkitTextDecorationColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        WebkitTextDecorationLine?: import("../../types").CustomValueType | (string & {}) | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grammar-error" | "line-through" | "overline" | "spelling-error" | "underline" | (import("../../types").CustomValueType | (string & {}) | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grammar-error" | "line-through" | "overline" | "spelling-error" | "underline" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grammar-error" | "line-through" | "overline" | "spelling-error" | "underline" | undefined)[]] | undefined;
        WebkitTextDecorationSkip?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "box-decoration" | "edges" | "leading-spaces" | "objects" | "spaces" | "trailing-spaces" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "box-decoration" | "edges" | "leading-spaces" | "objects" | "spaces" | "trailing-spaces" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "box-decoration" | "edges" | "leading-spaces" | "objects" | "spaces" | "trailing-spaces" | undefined)[]] | undefined;
        WebkitTextDecorationStyle?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "dashed" | "dotted" | "double" | "solid" | "wavy" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "dashed" | "dotted" | "double" | "solid" | "wavy" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "dashed" | "dotted" | "double" | "solid" | "wavy" | undefined)[]] | undefined;
        WebkitTextEmphasisColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        WebkitTextEmphasisPosition?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        WebkitTextEmphasisStyle?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | undefined)[]] | undefined;
        WebkitTextFillColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        WebkitTextOrientation?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "mixed" | "sideways" | "upright" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "mixed" | "sideways" | "upright" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "mixed" | "sideways" | "upright" | undefined)[]] | undefined;
        WebkitTextSizeAdjust?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | undefined)[]] | undefined;
        WebkitTextStrokeColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        WebkitTextStrokeWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        WebkitTextUnderlinePosition?: import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "from-font" | "under" | (import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "from-font" | "under" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "from-font" | "under" | undefined)[]] | undefined;
        WebkitTouchCallout?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "default" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "default" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "default" | undefined)[]] | undefined;
        WebkitTransform?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        WebkitTransformOrigin?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitTransformStyle?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flat" | "preserve-3d" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flat" | "preserve-3d" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "flat" | "preserve-3d" | undefined)[]] | undefined;
        WebkitTransitionDelay?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        WebkitTransitionDuration?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        WebkitTransitionProperty?: import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        WebkitTransitionTimingFunction?: import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        WebkitUserModify?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "read-only" | "read-write" | "read-write-plaintext-only" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "read-only" | "read-write" | "read-write-plaintext-only" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "read-only" | "read-write" | "read-write-plaintext-only" | undefined)[]] | undefined;
        WebkitUserSelect?: import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | (import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | undefined)[] | [null, ...(import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | undefined)[]] | undefined;
        WebkitWritingMode?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal-tb" | "sideways-lr" | "sideways-rl" | "vertical-lr" | "vertical-rl" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal-tb" | "sideways-lr" | "sideways-rl" | "vertical-lr" | "vertical-rl" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal-tb" | "sideways-lr" | "sideways-rl" | "vertical-lr" | "vertical-rl" | undefined)[]] | undefined;
        MozAnimation?: import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        MozBorderImage?: import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | (import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | undefined)[]] | undefined;
        MozColumnRule?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozColumns?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        MozTransition?: import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        msContentZoomLimit?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msContentZoomSnap?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | undefined)[]] | undefined;
        msFlex?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        msScrollLimit?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msScrollSnapX?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msScrollSnapY?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        msTransition?: import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        WebkitAnimation?: import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        WebkitBorderBefore?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitBorderImage?: import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | (import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | undefined)[]] | undefined;
        WebkitBorderRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitColumnRule?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitColumns?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        WebkitFlex?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        WebkitFlexFlow?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | "nowrap" | "wrap" | "wrap-reverse" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | "nowrap" | "wrap" | "wrap-reverse" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "column" | "column-reverse" | "row" | "row-reverse" | "nowrap" | "wrap" | "wrap-reverse" | undefined)[]] | undefined;
        WebkitMask?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitTextEmphasis?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "circle" | "dot" | "double-circle" | "filled" | "open" | "sesame" | "triangle" | undefined)[]] | undefined;
        WebkitTextStroke?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        WebkitTransition?: import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        boxAlign?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | undefined)[]] | undefined;
        boxDirection?: import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | (import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[]] | undefined;
        boxFlex?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        boxFlexGroup?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        boxLines?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "multiple" | "single" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "multiple" | "single" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "multiple" | "single" | undefined)[]] | undefined;
        boxOrdinalGroup?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        boxOrient?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | undefined)[]] | undefined;
        boxPack?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | undefined)[]] | undefined;
        clip?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | undefined)[]] | undefined;
        fontVariantAlternates?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "historical-forms" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "historical-forms" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "historical-forms" | undefined)[]] | undefined;
        gridColumnGap?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        gridGap?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        gridRowGap?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        imeMode?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "active" | "disabled" | "inactive" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "active" | "disabled" | "inactive" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "active" | "disabled" | "inactive" | undefined)[]] | undefined;
        offsetBlock?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        offsetBlockEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        offsetBlockStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        offsetInline?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        offsetInlineEnd?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        offsetInlineStart?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollSnapCoordinate?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollSnapDestination?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        scrollSnapPointsX?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        scrollSnapPointsY?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        scrollSnapTypeX?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | undefined)[]] | undefined;
        scrollSnapTypeY?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "mandatory" | "proximity" | undefined)[]] | undefined;
        scrollbarTrackColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        textCombineHorizontal?: import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | (import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "digits" | undefined)[]] | undefined;
        KhtmlBoxAlign?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | undefined)[]] | undefined;
        KhtmlBoxDirection?: import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | (import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[]] | undefined;
        KhtmlBoxFlex?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        KhtmlBoxFlexGroup?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        KhtmlBoxLines?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "multiple" | "single" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "multiple" | "single" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "multiple" | "single" | undefined)[]] | undefined;
        KhtmlBoxOrdinalGroup?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        KhtmlBoxOrient?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | undefined)[]] | undefined;
        KhtmlBoxPack?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | undefined)[]] | undefined;
        KhtmlLineBreak?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "strict" | "anywhere" | "loose" | undefined)[]] | undefined;
        KhtmlOpacity?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        KhtmlUserSelect?: import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | (import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | undefined)[] | [null, ...(import("../../types").CustomValueType | "contain" | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "text" | "-moz-none" | "element" | undefined)[]] | undefined;
        MozBackgroundClip?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[]] | undefined;
        MozBackgroundInlinePolicy?: import("../../types").CustomValueType | "slice" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "clone" | (import("../../types").CustomValueType | "slice" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "clone" | undefined)[] | [null, ...(import("../../types").CustomValueType | "slice" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "clone" | undefined)[]] | undefined;
        MozBackgroundOrigin?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | undefined)[]] | undefined;
        MozBackgroundSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozBinding?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        MozBorderRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozBorderRadiusBottomleft?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozBorderRadiusBottomright?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozBorderRadiusTopleft?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozBorderRadiusTopright?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozBoxAlign?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | undefined)[]] | undefined;
        MozBoxDirection?: import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | (import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[]] | undefined;
        MozBoxFlex?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        MozBoxOrdinalGroup?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        MozBoxOrient?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | undefined)[]] | undefined;
        MozBoxPack?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | undefined)[]] | undefined;
        MozBoxShadow?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        MozFloatEdge?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "margin-box" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "margin-box" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "border-box" | "content-box" | "padding-box" | "margin-box" | undefined)[]] | undefined;
        MozForceBrokenImageIcon?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        MozOpacity?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        MozOutline?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozOutlineColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "invert" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "invert" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "invert" | undefined)[]] | undefined;
        MozOutlineRadius?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozOutlineRadiusBottomleft?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozOutlineRadiusBottomright?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozOutlineRadiusTopleft?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozOutlineRadiusTopright?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        MozOutlineStyle?: import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | (import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "inset" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "hidden" | "dashed" | "dotted" | "double" | "solid" | "groove" | "outset" | "ridge" | undefined)[]] | undefined;
        MozOutlineWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        MozTextAlignLast?: import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "center" | "end" | "start" | "justify" | (import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "center" | "end" | "start" | "justify" | undefined)[] | [null, ...(import("../../types").CustomValueType | "left" | "right" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "center" | "end" | "start" | "justify" | undefined)[]] | undefined;
        MozTextDecorationColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        MozTextDecorationLine?: import("../../types").CustomValueType | (string & {}) | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grammar-error" | "line-through" | "overline" | "spelling-error" | "underline" | (import("../../types").CustomValueType | (string & {}) | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grammar-error" | "line-through" | "overline" | "spelling-error" | "underline" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "blink" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "grammar-error" | "line-through" | "overline" | "spelling-error" | "underline" | undefined)[]] | undefined;
        MozTextDecorationStyle?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "dashed" | "dotted" | "double" | "solid" | "wavy" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "dashed" | "dotted" | "double" | "solid" | "wavy" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "dashed" | "dotted" | "double" | "solid" | "wavy" | undefined)[]] | undefined;
        MozUserInput?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "disabled" | "enabled" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "disabled" | "enabled" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "auto" | "disabled" | "enabled" | undefined)[]] | undefined;
        msImeMode?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "active" | "disabled" | "inactive" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "active" | "disabled" | "inactive" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "normal" | "active" | "disabled" | "inactive" | undefined)[]] | undefined;
        msScrollbarTrackColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | undefined)[]] | undefined;
        OAnimation?: import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "normal" | "alternate" | "alternate-reverse" | "backwards" | "both" | "forwards" | "infinite" | "paused" | "running" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        OAnimationDelay?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        OAnimationDirection?: import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | (import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | "alternate" | "alternate-reverse" | undefined)[]] | undefined;
        OAnimationDuration?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        OAnimationFillMode?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "backwards" | "both" | "forwards" | undefined)[]] | undefined;
        OAnimationIterationCount?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | "infinite" | undefined)[]] | undefined;
        OAnimationName?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        OAnimationPlayState?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "paused" | "running" | undefined)[]] | undefined;
        OAnimationTimingFunction?: import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        OBackgroundSize?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        OBorderImage?: import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | (import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "repeat" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (number & {}) | "round" | "space" | "stretch" | undefined)[]] | undefined;
        OTransform?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        OTransition?: import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        OTransitionDelay?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        OTransitionDuration?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | undefined)[]] | undefined;
        OTransitionProperty?: import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "all" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        OTransitionTimingFunction?: import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | (import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "linear" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "ease" | "ease-in" | "ease-in-out" | "ease-out" | "step-end" | "step-start" | undefined)[]] | undefined;
        WebkitBoxAlign?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "baseline" | "end" | "start" | "stretch" | undefined)[]] | undefined;
        WebkitBoxDirection?: import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | (import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[] | [null, ...(import("../../types").CustomValueType | "reverse" | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "normal" | undefined)[]] | undefined;
        WebkitBoxFlex?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        WebkitBoxFlexGroup?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        WebkitBoxLines?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "multiple" | "single" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "multiple" | "single" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "multiple" | "single" | undefined)[]] | undefined;
        WebkitBoxOrdinalGroup?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        WebkitBoxOrient?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "horizontal" | "vertical" | "block-axis" | "inline-axis" | undefined)[]] | undefined;
        WebkitBoxPack?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "center" | "end" | "start" | "justify" | undefined)[]] | undefined;
        WebkitScrollSnapPointsX?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        WebkitScrollSnapPointsY?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        alignmentBaseline?: import("../../types").CustomValueType | "inherit" | "auto" | "after-edge" | "alphabetic" | "baseline" | "before-edge" | "central" | "hanging" | "ideographic" | "mathematical" | "middle" | "text-after-edge" | "text-before-edge" | (import("../../types").CustomValueType | "inherit" | "auto" | "after-edge" | "alphabetic" | "baseline" | "before-edge" | "central" | "hanging" | "ideographic" | "mathematical" | "middle" | "text-after-edge" | "text-before-edge" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inherit" | "auto" | "after-edge" | "alphabetic" | "baseline" | "before-edge" | "central" | "hanging" | "ideographic" | "mathematical" | "middle" | "text-after-edge" | "text-before-edge" | undefined)[]] | undefined;
        baselineShift?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        clipRule?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "evenodd" | "nonzero" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "evenodd" | "nonzero" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "evenodd" | "nonzero" | undefined)[]] | undefined;
        colorInterpolation?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "linearRGB" | "sRGB" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "linearRGB" | "sRGB" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "linearRGB" | "sRGB" | undefined)[]] | undefined;
        colorRendering?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "optimizeSpeed" | "optimizeQuality" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "optimizeSpeed" | "optimizeQuality" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "optimizeSpeed" | "optimizeQuality" | undefined)[]] | undefined;
        dominantBaseline?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "alphabetic" | "central" | "hanging" | "ideographic" | "mathematical" | "middle" | "text-after-edge" | "text-before-edge" | "no-change" | "reset-size" | "use-script" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "alphabetic" | "central" | "hanging" | "ideographic" | "mathematical" | "middle" | "text-after-edge" | "text-before-edge" | "no-change" | "reset-size" | "use-script" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "alphabetic" | "central" | "hanging" | "ideographic" | "mathematical" | "middle" | "text-after-edge" | "text-before-edge" | "no-change" | "reset-size" | "use-script" | undefined)[]] | undefined;
        fill?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "child" | "context-fill" | "context-stroke" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "child" | "context-fill" | "context-stroke" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "child" | "context-fill" | "context-stroke" | undefined)[]] | undefined;
        fillOpacity?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        fillRule?: import("../../types").CustomValueType | "inherit" | "evenodd" | "nonzero" | (import("../../types").CustomValueType | "inherit" | "evenodd" | "nonzero" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inherit" | "evenodd" | "nonzero" | undefined)[]] | undefined;
        floodColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "currentColor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "currentColor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "currentColor" | undefined)[]] | undefined;
        floodOpacity?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        glyphOrientationVertical?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | (number & {}) | undefined)[]] | undefined;
        lightingColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "currentColor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "currentColor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "currentColor" | undefined)[]] | undefined;
        marker?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        markerEnd?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        markerMid?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        markerStart?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | undefined)[]] | undefined;
        shapeRendering?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "geometricPrecision" | "optimizeSpeed" | "crispEdges" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "geometricPrecision" | "optimizeSpeed" | "crispEdges" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "geometricPrecision" | "optimizeSpeed" | "crispEdges" | undefined)[]] | undefined;
        stopColor?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "currentColor" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "currentColor" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "currentColor" | undefined)[]] | undefined;
        stopOpacity?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        stroke?: import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "child" | "context-fill" | "context-stroke" | (import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "child" | "context-fill" | "context-stroke" | undefined)[] | [null, ...(import("../../types").CustomValueType | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "aliceblue" | "antiquewhite" | "aqua" | "aquamarine" | "azure" | "beige" | "bisque" | "black" | "blanchedalmond" | "blue" | "blueviolet" | "brown" | "burlywood" | "cadetblue" | "chartreuse" | "chocolate" | "coral" | "cornflowerblue" | "cornsilk" | "crimson" | "cyan" | "darkblue" | "darkcyan" | "darkgoldenrod" | "darkgray" | "darkgreen" | "darkgrey" | "darkkhaki" | "darkmagenta" | "darkolivegreen" | "darkorange" | "darkorchid" | "darkred" | "darksalmon" | "darkseagreen" | "darkslateblue" | "darkslategray" | "darkslategrey" | "darkturquoise" | "darkviolet" | "deeppink" | "deepskyblue" | "dimgray" | "dimgrey" | "dodgerblue" | "firebrick" | "floralwhite" | "forestgreen" | "fuchsia" | "gainsboro" | "ghostwhite" | "gold" | "goldenrod" | "gray" | "green" | "greenyellow" | "grey" | "honeydew" | "hotpink" | "indianred" | "indigo" | "ivory" | "khaki" | "lavender" | "lavenderblush" | "lawngreen" | "lemonchiffon" | "lightblue" | "lightcoral" | "lightcyan" | "lightgoldenrodyellow" | "lightgray" | "lightgreen" | "lightgrey" | "lightpink" | "lightsalmon" | "lightseagreen" | "lightskyblue" | "lightslategray" | "lightslategrey" | "lightsteelblue" | "lightyellow" | "lime" | "limegreen" | "linen" | "magenta" | "maroon" | "mediumaquamarine" | "mediumblue" | "mediumorchid" | "mediumpurple" | "mediumseagreen" | "mediumslateblue" | "mediumspringgreen" | "mediumturquoise" | "mediumvioletred" | "midnightblue" | "mintcream" | "mistyrose" | "moccasin" | "navajowhite" | "navy" | "oldlace" | "olive" | "olivedrab" | "orange" | "orangered" | "orchid" | "palegoldenrod" | "palegreen" | "paleturquoise" | "palevioletred" | "papayawhip" | "peachpuff" | "peru" | "pink" | "plum" | "powderblue" | "purple" | "rebeccapurple" | "red" | "rosybrown" | "royalblue" | "saddlebrown" | "salmon" | "sandybrown" | "seagreen" | "seashell" | "sienna" | "silver" | "skyblue" | "slateblue" | "slategray" | "slategrey" | "snow" | "springgreen" | "steelblue" | "tan" | "teal" | "thistle" | "tomato" | "transparent" | "turquoise" | "violet" | "wheat" | "white" | "whitesmoke" | "yellow" | "yellowgreen" | "ActiveBorder" | "ActiveCaption" | "AppWorkspace" | "Background" | "ButtonFace" | "ButtonHighlight" | "ButtonShadow" | "ButtonText" | "CaptionText" | "GrayText" | "Highlight" | "HighlightText" | "InactiveBorder" | "InactiveCaption" | "InactiveCaptionText" | "InfoBackground" | "InfoText" | "Menu" | "MenuText" | "Scrollbar" | "ThreeDDarkShadow" | "ThreeDFace" | "ThreeDHighlight" | "ThreeDLightShadow" | "ThreeDShadow" | "Window" | "WindowFrame" | "WindowText" | "currentcolor" | "child" | "context-fill" | "context-stroke" | undefined)[]] | undefined;
        strokeDasharray?: string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | (number & {}) | undefined)[]] | undefined;
        strokeDashoffset?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        strokeLinecap?: import("../../types").CustomValueType | "inherit" | "round" | "butt" | "square" | (import("../../types").CustomValueType | "inherit" | "round" | "butt" | "square" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inherit" | "round" | "butt" | "square" | undefined)[]] | undefined;
        strokeLinejoin?: import("../../types").CustomValueType | "inherit" | "round" | "bevel" | "miter" | (import("../../types").CustomValueType | "inherit" | "round" | "bevel" | "miter" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inherit" | "round" | "bevel" | "miter" | undefined)[]] | undefined;
        strokeMiterlimit?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        strokeOpacity?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | (number & {}) | undefined)[]] | undefined;
        strokeWidth?: string | number | import("../../types").CustomValueType | (string & {}) | (string | number | import("../../types").CustomValueType | (string & {}) | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | (string & {}) | undefined)[]] | undefined;
        textAnchor?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "middle" | "end" | "start" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "middle" | "end" | "start" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "middle" | "end" | "start" | undefined)[]] | undefined;
        vectorEffect?: import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "non-scaling-stroke" | (import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "non-scaling-stroke" | undefined)[] | [null, ...(import("../../types").CustomValueType | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "none" | "non-scaling-stroke" | undefined)[]] | undefined;
        className?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        id?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        lang?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        max?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        media?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        method?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        min?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        name?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        style?: import("../../types").CustomValueType | import("react").CSSProperties | (import("../../types").CustomValueType | import("react").CSSProperties | undefined)[] | [null, ...(import("../../types").CustomValueType | import("react").CSSProperties | undefined)[]] | undefined;
        target?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        type?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        role?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        tabIndex?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        crossOrigin?: "" | import("../../types").CustomValueType | "anonymous" | "use-credentials" | ("" | import("../../types").CustomValueType | "anonymous" | "use-credentials" | undefined)[] | [null, ...("" | import("../../types").CustomValueType | "anonymous" | "use-credentials" | undefined)[]] | undefined;
        accentHeight?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        accumulate?: import("../../types").CustomValueType | "none" | "sum" | (import("../../types").CustomValueType | "none" | "sum" | undefined)[] | [null, ...(import("../../types").CustomValueType | "none" | "sum" | undefined)[]] | undefined;
        additive?: import("../../types").CustomValueType | "replace" | "sum" | (import("../../types").CustomValueType | "replace" | "sum" | undefined)[] | [null, ...(import("../../types").CustomValueType | "replace" | "sum" | undefined)[]] | undefined;
        allowReorder?: import("../../types").CustomValueType | "yes" | "no" | (import("../../types").CustomValueType | "yes" | "no" | undefined)[] | [null, ...(import("../../types").CustomValueType | "yes" | "no" | undefined)[]] | undefined;
        alphabetic?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        amplitude?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        arabicForm?: import("../../types").CustomValueType | "initial" | "medial" | "terminal" | "isolated" | (import("../../types").CustomValueType | "initial" | "medial" | "terminal" | "isolated" | undefined)[] | [null, ...(import("../../types").CustomValueType | "initial" | "medial" | "terminal" | "isolated" | undefined)[]] | undefined;
        ascent?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        attributeName?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        attributeType?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        autoReverse?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        azimuth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        baseFrequency?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        baseProfile?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        bbox?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        begin?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        bias?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        by?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        calcMode?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        capHeight?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        clipPathUnits?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        colorInterpolationFilters?: import("../../types").CustomValueType | "inherit" | "auto" | "linearRGB" | "sRGB" | (import("../../types").CustomValueType | "inherit" | "auto" | "linearRGB" | "sRGB" | undefined)[] | [null, ...(import("../../types").CustomValueType | "inherit" | "auto" | "linearRGB" | "sRGB" | undefined)[]] | undefined;
        colorProfile?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        contentScriptType?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        contentStyleType?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        cx?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        cy?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        d?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        decelerate?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        descent?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        diffuseConstant?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        divisor?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        dur?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        dx?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        dy?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        edgeMode?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        elevation?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        enableBackground?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        end?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        exponent?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        externalResourcesRequired?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        filterRes?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        filterUnits?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        focusable?: boolean | import("../../types").CustomValueType | "auto" | "true" | "false" | (boolean | import("../../types").CustomValueType | "auto" | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "auto" | "true" | "false" | undefined)[]] | undefined;
        format?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        from?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        fx?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        fy?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        g1?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        g2?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        glyphName?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        glyphOrientationHorizontal?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        glyphRef?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        gradientTransform?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        gradientUnits?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        hanging?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        horizAdvX?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        horizOriginX?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        href?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        ideographic?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        in2?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        in?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        intercept?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        k1?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        k2?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        k3?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        k4?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        k?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        kernelMatrix?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        kernelUnitLength?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        kerning?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        keyPoints?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        keySplines?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        keyTimes?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        lengthAdjust?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        limitingConeAngle?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        local?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        markerHeight?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        markerUnits?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        markerWidth?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        maskContentUnits?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        maskUnits?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        mathematical?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        mode?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        numOctaves?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        operator?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        orient?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        orientation?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        origin?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        overlinePosition?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        overlineThickness?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        panose1?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        path?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        pathLength?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        patternContentUnits?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        patternTransform?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        patternUnits?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        points?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        pointsAtX?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        pointsAtY?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        pointsAtZ?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        preserveAlpha?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        preserveAspectRatio?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        primitiveUnits?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        r?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        radius?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        refX?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        refY?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        renderingIntent?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        repeatCount?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        repeatDur?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        requiredExtensions?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        requiredFeatures?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        restart?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        result?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        rotate?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        rx?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        ry?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scale?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        seed?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        slope?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        spacing?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        specularConstant?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        specularExponent?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        speed?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        spreadMethod?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        startOffset?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        stdDeviation?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        stemh?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        stemv?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        stitchTiles?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        strikethroughPosition?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        strikethroughThickness?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        string?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        surfaceScale?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        systemLanguage?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        tableValues?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        targetX?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        targetY?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        textLength?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        to?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        u1?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        u2?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        underlinePosition?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        underlineThickness?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        unicode?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        unicodeRange?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        unitsPerEm?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        vAlphabetic?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        values?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        version?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        vertAdvY?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        vertOriginX?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        vertOriginY?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        vHanging?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        vIdeographic?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        viewBox?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        viewTarget?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        vMathematical?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        widths?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        x1?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        x2?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        x?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        xChannelSelector?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xHeight?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        xlinkActuate?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xlinkArcrole?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xlinkHref?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xlinkRole?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xlinkShow?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xlinkTitle?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xlinkType?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xmlBase?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xmlLang?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xmlns?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xmlnsXlink?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        xmlSpace?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        y1?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        y2?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        y?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        yChannelSelector?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        z?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        zoomAndPan?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-activedescendant'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-atomic'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-autocomplete'?: import("../../types").CustomValueType | "none" | "inline" | "both" | "list" | (import("../../types").CustomValueType | "none" | "inline" | "both" | "list" | undefined)[] | [null, ...(import("../../types").CustomValueType | "none" | "inline" | "both" | "list" | undefined)[]] | undefined;
        'aria-busy'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-checked'?: boolean | import("../../types").CustomValueType | "true" | "false" | "mixed" | (boolean | import("../../types").CustomValueType | "true" | "false" | "mixed" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | "mixed" | undefined)[]] | undefined;
        'aria-colcount'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-colindex'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-colspan'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-controls'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-current'?: boolean | import("../../types").CustomValueType | "time" | "true" | "false" | "page" | "step" | "location" | "date" | (boolean | import("../../types").CustomValueType | "time" | "true" | "false" | "page" | "step" | "location" | "date" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "time" | "true" | "false" | "page" | "step" | "location" | "date" | undefined)[]] | undefined;
        'aria-describedby'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-details'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-disabled'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-dropeffect'?: import("../../types").CustomValueType | "link" | "none" | "copy" | "move" | "execute" | "popup" | (import("../../types").CustomValueType | "link" | "none" | "copy" | "move" | "execute" | "popup" | undefined)[] | [null, ...(import("../../types").CustomValueType | "link" | "none" | "copy" | "move" | "execute" | "popup" | undefined)[]] | undefined;
        'aria-errormessage'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-expanded'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-flowto'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-grabbed'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-haspopup'?: boolean | import("../../types").CustomValueType | "grid" | "dialog" | "menu" | "true" | "false" | "listbox" | "tree" | (boolean | import("../../types").CustomValueType | "grid" | "dialog" | "menu" | "true" | "false" | "listbox" | "tree" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "grid" | "dialog" | "menu" | "true" | "false" | "listbox" | "tree" | undefined)[]] | undefined;
        'aria-hidden'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-invalid'?: boolean | import("../../types").CustomValueType | "true" | "false" | "grammar" | "spelling" | (boolean | import("../../types").CustomValueType | "true" | "false" | "grammar" | "spelling" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | "grammar" | "spelling" | undefined)[]] | undefined;
        'aria-keyshortcuts'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-label'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-labelledby'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-level'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-live'?: import("../../types").CustomValueType | "off" | "assertive" | "polite" | (import("../../types").CustomValueType | "off" | "assertive" | "polite" | undefined)[] | [null, ...(import("../../types").CustomValueType | "off" | "assertive" | "polite" | undefined)[]] | undefined;
        'aria-modal'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-multiline'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-multiselectable'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-orientation'?: import("../../types").CustomValueType | "horizontal" | "vertical" | (import("../../types").CustomValueType | "horizontal" | "vertical" | undefined)[] | [null, ...(import("../../types").CustomValueType | "horizontal" | "vertical" | undefined)[]] | undefined;
        'aria-owns'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-placeholder'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-posinset'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-pressed'?: boolean | import("../../types").CustomValueType | "true" | "false" | "mixed" | (boolean | import("../../types").CustomValueType | "true" | "false" | "mixed" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | "mixed" | undefined)[]] | undefined;
        'aria-readonly'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-relevant'?: import("../../types").CustomValueType | "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | (import("../../types").CustomValueType | "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined)[] | [null, ...(import("../../types").CustomValueType | "all" | "text" | "additions" | "additions removals" | "additions text" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined)[]] | undefined;
        'aria-required'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-roledescription'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-rowcount'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-rowindex'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-rowspan'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-selected'?: boolean | import("../../types").CustomValueType | "true" | "false" | (boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[] | [null, ...(boolean | import("../../types").CustomValueType | "true" | "false" | undefined)[]] | undefined;
        'aria-setsize'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-sort'?: import("../../types").CustomValueType | "none" | "ascending" | "descending" | "other" | (import("../../types").CustomValueType | "none" | "ascending" | "descending" | "other" | undefined)[] | [null, ...(import("../../types").CustomValueType | "none" | "ascending" | "descending" | "other" | undefined)[]] | undefined;
        'aria-valuemax'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-valuemin'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-valuenow'?: number | import("../../types").CustomValueType | (number | import("../../types").CustomValueType | undefined)[] | [null, ...(number | import("../../types").CustomValueType | undefined)[]] | undefined;
        'aria-valuetext'?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        children?: string | number | boolean | {} | import("../../types").CustomValueType | import("react").ReactElement<any, string | ((props: any) => import("react").ReactElement<any, string | any | (new (props: any) => import("react").Component<any, any, any>)> | null) | (new (props: any) => import("react").Component<any, any, any>)> | import("react").ReactNodeArray | import("react").ReactPortal | (string | number | boolean | {} | import("../../types").CustomValueType | import("react").ReactElement<any, string | ((props: any) => import("react").ReactElement<any, string | any | (new (props: any) => import("react").Component<any, any, any>)> | null) | (new (props: any) => import("react").Component<any, any, any>)> | import("react").ReactNodeArray | import("react").ReactPortal | null | undefined)[] | [null, ...(string | number | boolean | {} | import("../../types").CustomValueType | import("react").ReactElement<any, string | ((props: any) => import("react").ReactElement<any, string | any | (new (props: any) => import("react").Component<any, any, any>)> | null) | (new (props: any) => import("react").Component<any, any, any>)> | import("react").ReactNodeArray | import("react").ReactPortal | null | undefined)[]] | null | undefined;
        dangerouslySetInnerHTML?: import("../../types").CustomValueType | {
            __html: string;
        } | (import("../../types").CustomValueType | {
            __html: string;
        } | undefined)[] | [null, ...(import("../../types").CustomValueType | {
            __html: string;
        } | undefined)[]] | undefined;
        onCopy?: import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onCopyCapture?: import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onCut?: import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onCutCapture?: import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPaste?: import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPasteCapture?: import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").ClipboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onCompositionEnd?: import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onCompositionEndCapture?: import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onCompositionStart?: import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onCompositionStartCapture?: import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onCompositionUpdate?: import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onCompositionUpdateCapture?: import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").CompositionEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onFocus?: import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onFocusCapture?: import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onBlur?: import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onBlurCapture?: import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FocusEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onChange?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onChangeCapture?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onBeforeInput?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onBeforeInputCapture?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onInput?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onInputCapture?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onReset?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onResetCapture?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onSubmit?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onSubmitCapture?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onInvalid?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onInvalidCapture?: import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").FormEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onLoad?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onLoadCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onError?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onErrorCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onKeyDown?: import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onKeyDownCapture?: import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onKeyPress?: import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onKeyPressCapture?: import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onKeyUp?: import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onKeyUpCapture?: import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").KeyboardEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onAbort?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onAbortCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onCanPlay?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onCanPlayCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onCanPlayThrough?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onCanPlayThroughCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onDurationChange?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onDurationChangeCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onEmptied?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onEmptiedCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onEncrypted?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onEncryptedCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onEnded?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onEndedCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onLoadedData?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onLoadedDataCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onLoadedMetadata?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onLoadedMetadataCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onLoadStart?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onLoadStartCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onPause?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onPauseCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onPlay?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onPlayCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onPlaying?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onPlayingCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onProgress?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onProgressCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onRateChange?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onRateChangeCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onSeeked?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onSeekedCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onSeeking?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onSeekingCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onStalled?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onStalledCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onSuspend?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onSuspendCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onTimeUpdate?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onTimeUpdateCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onVolumeChange?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onVolumeChangeCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onWaiting?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onWaitingCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onAuxClick?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onAuxClickCapture?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onClick?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onClickCapture?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onContextMenu?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onContextMenuCapture?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onDoubleClick?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onDoubleClickCapture?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onDrag?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragCapture?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragEnd?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragEndCapture?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragEnter?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragEnterCapture?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragExit?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragExitCapture?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragLeave?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragLeaveCapture?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragOver?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragOverCapture?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragStart?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDragStartCapture?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDrop?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onDropCapture?: import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").DragEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onMouseDown?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onMouseDownCapture?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onMouseEnter?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onMouseLeave?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onMouseMove?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onMouseMoveCapture?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onMouseOut?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onMouseOutCapture?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onMouseOver?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onMouseOverCapture?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onMouseUp?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onMouseUpCapture?: import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").MouseEvent<SVGElement, MouseEvent>) => void) | undefined)[]] | undefined;
        onSelect?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onSelectCapture?: import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | (import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").SyntheticEvent<SVGElement, Event>) => void) | undefined)[]] | undefined;
        onTouchCancel?: import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onTouchCancelCapture?: import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onTouchEnd?: import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onTouchEndCapture?: import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onTouchMove?: import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onTouchMoveCapture?: import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onTouchStart?: import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onTouchStartCapture?: import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").TouchEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerDown?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerDownCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerMove?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerMoveCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerUp?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerUpCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerCancel?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerCancelCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerEnter?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerEnterCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerLeave?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerLeaveCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerOver?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerOverCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerOut?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onPointerOutCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onGotPointerCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onGotPointerCaptureCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onLostPointerCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onLostPointerCaptureCapture?: import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").PointerEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onScroll?: import("../../types").CustomValueType | ((event: import("react").UIEvent<SVGElement, UIEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").UIEvent<SVGElement, UIEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").UIEvent<SVGElement, UIEvent>) => void) | undefined)[]] | undefined;
        onScrollCapture?: import("../../types").CustomValueType | ((event: import("react").UIEvent<SVGElement, UIEvent>) => void) | (import("../../types").CustomValueType | ((event: import("react").UIEvent<SVGElement, UIEvent>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").UIEvent<SVGElement, UIEvent>) => void) | undefined)[]] | undefined;
        onWheel?: import("../../types").CustomValueType | ((event: import("react").WheelEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").WheelEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").WheelEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onWheelCapture?: import("../../types").CustomValueType | ((event: import("react").WheelEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").WheelEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").WheelEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onAnimationStart?: import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onAnimationStartCapture?: import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onAnimationEnd?: import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onAnimationEndCapture?: import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onAnimationIteration?: import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onAnimationIterationCapture?: import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").AnimationEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onTransitionEnd?: import("../../types").CustomValueType | ((event: import("react").TransitionEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").TransitionEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").TransitionEvent<SVGElement>) => void) | undefined)[]] | undefined;
        onTransitionEndCapture?: import("../../types").CustomValueType | ((event: import("react").TransitionEvent<SVGElement>) => void) | (import("../../types").CustomValueType | ((event: import("react").TransitionEvent<SVGElement>) => void) | undefined)[] | [null, ...(import("../../types").CustomValueType | ((event: import("react").TransitionEvent<SVGElement>) => void) | undefined)[]] | undefined;
        translateX?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        translateY?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        translateZ?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        rotateX?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        rotateY?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        rotateZ?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scaleX?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scaleY?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        scaleZ?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        skew?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        skewX?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        skewY?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        originX?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        originY?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        originZ?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        perspective?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        transformPerspective?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        size?: string | number | import("../../types").CustomValueType | (string | number | import("../../types").CustomValueType | undefined)[] | [null, ...(string | number | import("../../types").CustomValueType | undefined)[]] | undefined;
        shadow?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        image?: string | import("../../types").CustomValueType | (string | import("../../types").CustomValueType | undefined)[] | [null, ...(string | import("../../types").CustomValueType | undefined)[]] | undefined;
        transition: (import("../../types").Orchestration & import("../../types").Repeat & import("../../types").Tween) | (import("../../types").Orchestration & import("../../types").Repeat & import("../../types").Spring) | (import("../../types").Orchestration & import("../../types").Repeat & import("../../types").Inertia) | (import("../../types").Orchestration & import("../../types").Repeat & import("../../types").Keyframes) | (import("../../types").Orchestration & import("../../types").Repeat & import("../../types").Just) | (import("../../types").Orchestration & import("../../types").Repeat & import("../../types").None) | (import("../../types").Orchestration & import("../../types").Repeat & import("../../types").PermissiveTransitionDefinition) | (import("../../types").Orchestration & import("../../types").Repeat & {
            [key: string]: import("../../types").TransitionDefinition;
        }) | undefined;
        transitionEnd: import("../../types").MakeCustomValueType<Pick<import("react").CSSProperties, "alignContent" | "alignItems" | "alignSelf" | "animationDelay" | "animationDirection" | "animationDuration" | "animationFillMode" | "animationIterationCount" | "animationName" | "animationPlayState" | "animationTimingFunction" | "appearance" | "aspectRatio" | "backdropFilter" | "backfaceVisibility" | "backgroundAttachment" | "backgroundBlendMode" | "backgroundClip" | "backgroundColor" | "backgroundImage" | "backgroundOrigin" | "backgroundPosition" | "backgroundPositionX" | "backgroundPositionY" | "backgroundRepeat" | "backgroundSize" | "blockOverflow" | "blockSize" | "borderBlockColor" | "borderBlockEndColor" | "borderBlockEndStyle" | "borderBlockEndWidth" | "borderBlockStartColor" | "borderBlockStartStyle" | "borderBlockStartWidth" | "borderBlockStyle" | "borderBlockWidth" | "borderBottomColor" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderBottomStyle" | "borderBottomWidth" | "borderCollapse" | "borderEndEndRadius" | "borderEndStartRadius" | "borderImageOutset" | "borderImageRepeat" | "borderImageSlice" | "borderImageSource" | "borderImageWidth" | "borderInlineColor" | "borderInlineEndColor" | "borderInlineEndStyle" | "borderInlineEndWidth" | "borderInlineStartColor" | "borderInlineStartStyle" | "borderInlineStartWidth" | "borderInlineStyle" | "borderInlineWidth" | "borderLeftColor" | "borderLeftStyle" | "borderLeftWidth" | "borderRightColor" | "borderRightStyle" | "borderRightWidth" | "borderSpacing" | "borderStartEndRadius" | "borderStartStartRadius" | "borderTopColor" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderTopStyle" | "borderTopWidth" | "bottom" | "boxDecorationBreak" | "boxShadow" | "boxSizing" | "breakAfter" | "breakBefore" | "breakInside" | "captionSide" | "caretColor" | "clear" | "clipPath" | "color" | "colorAdjust" | "columnCount" | "columnFill" | "columnGap" | "columnRuleColor" | "columnRuleStyle" | "columnRuleWidth" | "columnSpan" | "columnWidth" | "contain" | "content" | "counterIncrement" | "counterReset" | "counterSet" | "cursor" | "direction" | "display" | "emptyCells" | "filter" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "float" | "fontFamily" | "fontFeatureSettings" | "fontKerning" | "fontLanguageOverride" | "fontOpticalSizing" | "fontSize" | "fontSizeAdjust" | "fontSmooth" | "fontStretch" | "fontStyle" | "fontSynthesis" | "fontVariant" | "fontVariantCaps" | "fontVariantEastAsian" | "fontVariantLigatures" | "fontVariantNumeric" | "fontVariantPosition" | "fontVariationSettings" | "fontWeight" | "gridAutoColumns" | "gridAutoFlow" | "gridAutoRows" | "gridColumnEnd" | "gridColumnStart" | "gridRowEnd" | "gridRowStart" | "gridTemplateAreas" | "gridTemplateColumns" | "gridTemplateRows" | "hangingPunctuation" | "height" | "hyphens" | "imageOrientation" | "imageRendering" | "imageResolution" | "initialLetter" | "inlineSize" | "inset" | "insetBlock" | "insetBlockEnd" | "insetBlockStart" | "insetInline" | "insetInlineEnd" | "insetInlineStart" | "isolation" | "justifyContent" | "justifyItems" | "justifySelf" | "left" | "letterSpacing" | "lineBreak" | "lineHeight" | "lineHeightStep" | "listStyleImage" | "listStylePosition" | "listStyleType" | "marginBlock" | "marginBlockEnd" | "marginBlockStart" | "marginBottom" | "marginInline" | "marginInlineEnd" | "marginInlineStart" | "marginLeft" | "marginRight" | "marginTop" | "maskBorderMode" | "maskBorderOutset" | "maskBorderRepeat" | "maskBorderSlice" | "maskBorderSource" | "maskBorderWidth" | "maskClip" | "maskComposite" | "maskImage" | "maskMode" | "maskOrigin" | "maskPosition" | "maskRepeat" | "maskSize" | "maskType" | "maxBlockSize" | "maxHeight" | "maxInlineSize" | "maxLines" | "maxWidth" | "minBlockSize" | "minHeight" | "minInlineSize" | "minWidth" | "mixBlendMode" | "motionDistance" | "motionPath" | "motionRotation" | "objectFit" | "objectPosition" | "offsetAnchor" | "offsetDistance" | "offsetPath" | "offsetRotate" | "offsetRotation" | "opacity" | "order" | "orphans" | "outlineColor" | "outlineOffset" | "outlineStyle" | "outlineWidth" | "overflowAnchor" | "overflowBlock" | "overflowClipBox" | "overflowInline" | "overflowWrap" | "overflowX" | "overflowY" | "overscrollBehavior" | "overscrollBehaviorBlock" | "overscrollBehaviorInline" | "overscrollBehaviorX" | "overscrollBehaviorY" | "paddingBlock" | "paddingBlockEnd" | "paddingBlockStart" | "paddingBottom" | "paddingInline" | "paddingInlineEnd" | "paddingInlineStart" | "paddingLeft" | "paddingRight" | "paddingTop" | "pageBreakAfter" | "pageBreakBefore" | "pageBreakInside" | "paintOrder" | "perspectiveOrigin" | "placeContent" | "pointerEvents" | "position" | "quotes" | "resize" | "right" | "rowGap" | "rubyAlign" | "rubyMerge" | "rubyPosition" | "scrollBehavior" | "scrollMargin" | "scrollMarginBlock" | "scrollMarginBlockEnd" | "scrollMarginBlockStart" | "scrollMarginBottom" | "scrollMarginInline" | "scrollMarginInlineEnd" | "scrollMarginInlineStart" | "scrollMarginLeft" | "scrollMarginRight" | "scrollMarginTop" | "scrollPadding" | "scrollPaddingBlock" | "scrollPaddingBlockEnd" | "scrollPaddingBlockStart" | "scrollPaddingBottom" | "scrollPaddingInline" | "scrollPaddingInlineEnd" | "scrollPaddingInlineStart" | "scrollPaddingLeft" | "scrollPaddingRight" | "scrollPaddingTop" | "scrollSnapAlign" | "scrollSnapMargin" | "scrollSnapMarginBottom" | "scrollSnapMarginLeft" | "scrollSnapMarginRight" | "scrollSnapMarginTop" | "scrollSnapStop" | "scrollSnapType" | "scrollbarColor" | "scrollbarWidth" | "shapeImageThreshold" | "shapeMargin" | "shapeOutside" | "tabSize" | "tableLayout" | "textAlign" | "textAlignLast" | "textCombineUpright" | "textDecorationColor" | "textDecorationLine" | "textDecorationSkip" | "textDecorationSkipInk" | "textDecorationStyle" | "textDecorationThickness" | "textDecorationWidth" | "textEmphasisColor" | "textEmphasisPosition" | "textEmphasisStyle" | "textIndent" | "textJustify" | "textOrientation" | "textOverflow" | "textRendering" | "textShadow" | "textSizeAdjust" | "textTransform" | "textUnderlineOffset" | "textUnderlinePosition" | "top" | "touchAction" | "transform" | "transformBox" | "transformOrigin" | "transformStyle" | "transitionDelay" | "transitionDuration" | "transitionProperty" | "transitionTimingFunction" | "translate" | "unicodeBidi" | "userSelect" | "verticalAlign" | "visibility" | "whiteSpace" | "widows" | "width" | "willChange" | "wordBreak" | "wordSpacing" | "wordWrap" | "writingMode" | "zIndex" | "zoom" | "all" | "animation" | "background" | "border" | "borderBlock" | "borderBlockEnd" | "borderBlockStart" | "borderBottom" | "borderColor" | "borderImage" | "borderInline" | "borderInlineEnd" | "borderInlineStart" | "borderLeft" | "borderRadius" | "borderRight" | "borderStyle" | "borderTop" | "borderWidth" | "columnRule" | "columns" | "flex" | "flexFlow" | "font" | "gap" | "grid" | "gridArea" | "gridColumn" | "gridRow" | "gridTemplate" | "lineClamp" | "listStyle" | "margin" | "mask" | "maskBorder" | "motion" | "offset" | "outline" | "overflow" | "padding" | "placeItems" | "placeSelf" | "textDecoration" | "textEmphasis" | "MozAnimationDelay" | "MozAnimationDirection" | "MozAnimationDuration" | "MozAnimationFillMode" | "MozAnimationIterationCount" | "MozAnimationName" | "MozAnimationPlayState" | "MozAnimationTimingFunction" | "MozAppearance" | "MozBackfaceVisibility" | "MozBorderBottomColors" | "MozBorderEndColor" | "MozBorderEndStyle" | "MozBorderEndWidth" | "MozBorderLeftColors" | "MozBorderRightColors" | "MozBorderStartColor" | "MozBorderStartStyle" | "MozBorderTopColors" | "MozBoxSizing" | "MozColumnCount" | "MozColumnFill" | "MozColumnGap" | "MozColumnRuleColor" | "MozColumnRuleStyle" | "MozColumnRuleWidth" | "MozColumnWidth" | "MozContextProperties" | "MozFontFeatureSettings" | "MozFontLanguageOverride" | "MozHyphens" | "MozImageRegion" | "MozMarginEnd" | "MozMarginStart" | "MozOrient" | "MozOsxFontSmoothing" | "MozPaddingEnd" | "MozPaddingStart" | "MozPerspective" | "MozPerspectiveOrigin" | "MozStackSizing" | "MozTabSize" | "MozTextBlink" | "MozTextSizeAdjust" | "MozTransformOrigin" | "MozTransformStyle" | "MozTransitionDelay" | "MozTransitionDuration" | "MozTransitionProperty" | "MozTransitionTimingFunction" | "MozUserFocus" | "MozUserModify" | "MozUserSelect" | "MozWindowDragging" | "MozWindowShadow" | "msAccelerator" | "msAlignSelf" | "msBlockProgression" | "msContentZoomChaining" | "msContentZoomLimitMax" | "msContentZoomLimitMin" | "msContentZoomSnapPoints" | "msContentZoomSnapType" | "msContentZooming" | "msFilter" | "msFlexDirection" | "msFlexPositive" | "msFlowFrom" | "msFlowInto" | "msGridColumns" | "msGridRows" | "msHighContrastAdjust" | "msHyphenateLimitChars" | "msHyphenateLimitLines" | "msHyphenateLimitZone" | "msHyphens" | "msImeAlign" | "msLineBreak" | "msOrder" | "msOverflowStyle" | "msOverflowX" | "msOverflowY" | "msScrollChaining" | "msScrollLimitXMax" | "msScrollLimitXMin" | "msScrollLimitYMax" | "msScrollLimitYMin" | "msScrollRails" | "msScrollSnapPointsX" | "msScrollSnapPointsY" | "msScrollSnapType" | "msScrollTranslation" | "msScrollbar3dlightColor" | "msScrollbarArrowColor" | "msScrollbarBaseColor" | "msScrollbarDarkshadowColor" | "msScrollbarFaceColor" | "msScrollbarHighlightColor" | "msScrollbarShadowColor" | "msTextAutospace" | "msTextCombineHorizontal" | "msTextOverflow" | "msTouchAction" | "msTouchSelect" | "msTransform" | "msTransformOrigin" | "msTransitionDelay" | "msTransitionDuration" | "msTransitionProperty" | "msTransitionTimingFunction" | "msUserSelect" | "msWordBreak" | "msWrapFlow" | "msWrapMargin" | "msWrapThrough" | "msWritingMode" | "OObjectFit" | "OObjectPosition" | "OTabSize" | "OTextOverflow" | "OTransformOrigin" | "WebkitAlignContent" | "WebkitAlignItems" | "WebkitAlignSelf" | "WebkitAnimationDelay" | "WebkitAnimationDirection" | "WebkitAnimationDuration" | "WebkitAnimationFillMode" | "WebkitAnimationIterationCount" | "WebkitAnimationName" | "WebkitAnimationPlayState" | "WebkitAnimationTimingFunction" | "WebkitAppearance" | "WebkitBackdropFilter" | "WebkitBackfaceVisibility" | "WebkitBackgroundClip" | "WebkitBackgroundOrigin" | "WebkitBackgroundSize" | "WebkitBorderBeforeColor" | "WebkitBorderBeforeStyle" | "WebkitBorderBeforeWidth" | "WebkitBorderBottomLeftRadius" | "WebkitBorderBottomRightRadius" | "WebkitBorderImageSlice" | "WebkitBorderTopLeftRadius" | "WebkitBorderTopRightRadius" | "WebkitBoxDecorationBreak" | "WebkitBoxReflect" | "WebkitBoxShadow" | "WebkitBoxSizing" | "WebkitClipPath" | "WebkitColumnCount" | "WebkitColumnFill" | "WebkitColumnGap" | "WebkitColumnRuleColor" | "WebkitColumnRuleStyle" | "WebkitColumnRuleWidth" | "WebkitColumnSpan" | "WebkitColumnWidth" | "WebkitFilter" | "WebkitFlexBasis" | "WebkitFlexDirection" | "WebkitFlexGrow" | "WebkitFlexShrink" | "WebkitFlexWrap" | "WebkitFontFeatureSettings" | "WebkitFontKerning" | "WebkitFontSmoothing" | "WebkitFontVariantLigatures" | "WebkitHyphens" | "WebkitJustifyContent" | "WebkitLineBreak" | "WebkitLineClamp" | "WebkitMarginEnd" | "WebkitMarginStart" | "WebkitMaskAttachment" | "WebkitMaskClip" | "WebkitMaskComposite" | "WebkitMaskImage" | "WebkitMaskOrigin" | "WebkitMaskPosition" | "WebkitMaskPositionX" | "WebkitMaskPositionY" | "WebkitMaskRepeat" | "WebkitMaskRepeatX" | "WebkitMaskRepeatY" | "WebkitMaskSize" | "WebkitMaxInlineSize" | "WebkitOrder" | "WebkitOverflowScrolling" | "WebkitPaddingEnd" | "WebkitPaddingStart" | "WebkitPerspective" | "WebkitPerspectiveOrigin" | "WebkitPrintColorAdjust" | "WebkitScrollSnapType" | "WebkitShapeMargin" | "WebkitTapHighlightColor" | "WebkitTextCombine" | "WebkitTextDecorationColor" | "WebkitTextDecorationLine" | "WebkitTextDecorationSkip" | "WebkitTextDecorationStyle" | "WebkitTextEmphasisColor" | "WebkitTextEmphasisPosition" | "WebkitTextEmphasisStyle" | "WebkitTextFillColor" | "WebkitTextOrientation" | "WebkitTextSizeAdjust" | "WebkitTextStrokeColor" | "WebkitTextStrokeWidth" | "WebkitTextUnderlinePosition" | "WebkitTouchCallout" | "WebkitTransform" | "WebkitTransformOrigin" | "WebkitTransformStyle" | "WebkitTransitionDelay" | "WebkitTransitionDuration" | "WebkitTransitionProperty" | "WebkitTransitionTimingFunction" | "WebkitUserModify" | "WebkitUserSelect" | "WebkitWritingMode" | "MozAnimation" | "MozBorderImage" | "MozColumnRule" | "MozColumns" | "MozTransition" | "msContentZoomLimit" | "msContentZoomSnap" | "msFlex" | "msScrollLimit" | "msScrollSnapX" | "msScrollSnapY" | "msTransition" | "WebkitAnimation" | "WebkitBorderBefore" | "WebkitBorderImage" | "WebkitBorderRadius" | "WebkitColumnRule" | "WebkitColumns" | "WebkitFlex" | "WebkitFlexFlow" | "WebkitMask" | "WebkitTextEmphasis" | "WebkitTextStroke" | "WebkitTransition" | "boxAlign" | "boxDirection" | "boxFlex" | "boxFlexGroup" | "boxLines" | "boxOrdinalGroup" | "boxOrient" | "boxPack" | "clip" | "fontVariantAlternates" | "gridColumnGap" | "gridGap" | "gridRowGap" | "imeMode" | "offsetBlock" | "offsetBlockEnd" | "offsetBlockStart" | "offsetInline" | "offsetInlineEnd" | "offsetInlineStart" | "scrollSnapCoordinate" | "scrollSnapDestination" | "scrollSnapPointsX" | "scrollSnapPointsY" | "scrollSnapTypeX" | "scrollSnapTypeY" | "scrollbarTrackColor" | "textCombineHorizontal" | "KhtmlBoxAlign" | "KhtmlBoxDirection" | "KhtmlBoxFlex" | "KhtmlBoxFlexGroup" | "KhtmlBoxLines" | "KhtmlBoxOrdinalGroup" | "KhtmlBoxOrient" | "KhtmlBoxPack" | "KhtmlLineBreak" | "KhtmlOpacity" | "KhtmlUserSelect" | "MozBackgroundClip" | "MozBackgroundInlinePolicy" | "MozBackgroundOrigin" | "MozBackgroundSize" | "MozBinding" | "MozBorderRadius" | "MozBorderRadiusBottomleft" | "MozBorderRadiusBottomright" | "MozBorderRadiusTopleft" | "MozBorderRadiusTopright" | "MozBoxAlign" | "MozBoxDirection" | "MozBoxFlex" | "MozBoxOrdinalGroup" | "MozBoxOrient" | "MozBoxPack" | "MozBoxShadow" | "MozFloatEdge" | "MozForceBrokenImageIcon" | "MozOpacity" | "MozOutline" | "MozOutlineColor" | "MozOutlineRadius" | "MozOutlineRadiusBottomleft" | "MozOutlineRadiusBottomright" | "MozOutlineRadiusTopleft" | "MozOutlineRadiusTopright" | "MozOutlineStyle" | "MozOutlineWidth" | "MozTextAlignLast" | "MozTextDecorationColor" | "MozTextDecorationLine" | "MozTextDecorationStyle" | "MozUserInput" | "msImeMode" | "msScrollbarTrackColor" | "OAnimation" | "OAnimationDelay" | "OAnimationDirection" | "OAnimationDuration" | "OAnimationFillMode" | "OAnimationIterationCount" | "OAnimationName" | "OAnimationPlayState" | "OAnimationTimingFunction" | "OBackgroundSize" | "OBorderImage" | "OTransform" | "OTransition" | "OTransitionDelay" | "OTransitionDuration" | "OTransitionProperty" | "OTransitionTimingFunction" | "WebkitBoxAlign" | "WebkitBoxDirection" | "WebkitBoxFlex" | "WebkitBoxFlexGroup" | "WebkitBoxLines" | "WebkitBoxOrdinalGroup" | "WebkitBoxOrient" | "WebkitBoxPack" | "WebkitScrollSnapPointsX" | "WebkitScrollSnapPointsY" | "alignmentBaseline" | "baselineShift" | "clipRule" | "colorInterpolation" | "colorRendering" | "dominantBaseline" | "fill" | "fillOpacity" | "fillRule" | "floodColor" | "floodOpacity" | "glyphOrientationVertical" | "lightingColor" | "marker" | "markerEnd" | "markerMid" | "markerStart" | "shapeRendering" | "stopColor" | "stopOpacity" | "stroke" | "strokeDasharray" | "strokeDashoffset" | "strokeLinecap" | "strokeLinejoin" | "strokeMiterlimit" | "strokeOpacity" | "strokeWidth" | "textAnchor" | "vectorEffect"> & import("react").SVGAttributes<SVGElement> & import("../../motion/types").TransformProperties & import("../../motion/types").CustomStyles> | undefined;
    };
    /**
     * ========================================
     * Layout
     * ========================================
     */
    isLayoutProjectionEnabled: boolean;
    enableLayoutProjection(): void;
    /**
     * A set of layout update event handlers. These are only called once all layouts have been read,
     * making it safe to perform DOM write operations.
     */
    private layoutUpdateListeners;
    private layoutMeasureListeners;
    private viewportBoxUpdateListeners;
    /**
     * Keep track of whether the viewport box has been updated since the last render.
     * If it has, we want to fire the onViewportBoxUpdate listener.
     */
    private hasViewportBoxUpdated;
    /**
     * Optional id. If set, and this is the child of an AnimateSharedLayout component,
     * the targetBox can be transferred to a new component with the same ID.
     */
    layoutId?: string;
    /**
     * The measured bounding box as it exists on the page with no transforms applied.
     *
     * To calculate the visual output of a component in any given frame, we:
     *
     *   1. box -> boxCorrected
     *      Apply the delta between the tree transform when the box was measured and
     *      the tree transform in this frame to the box
     *   2. targetBox -> targetBoxFinal
     *      Apply the VisualElement's `transform` properties to the targetBox
     *   3. Calculate the delta between boxCorrected and targetBoxFinal and apply
     *      it as a transform style.
     */
    box: AxisBox2D;
    /**
     * The `box` layout with transforms applied from up the
     * tree. We use this as the final bounding box from which we calculate a transform
     * delta to our desired visual position on any given frame.
     *
     * This is considered mutable to avoid object creation on each frame.
     */
    private boxCorrected;
    /**
     * The visual target we want to project our component into on a given frame
     * before applying transforms defined in `animate` or `style`.
     *
     * This is considered mutable to avoid object creation on each frame.
     */
    targetBox: AxisBox2D;
    /**
     * The visual target we want to project our component into on a given frame
     * before applying transforms defined in `animate` or `style`.
     *
     * This is considered mutable to avoid object creation on each frame.
     */
    protected targetBoxFinal: AxisBox2D;
    /**
     * Can be used to store a snapshot of the measured viewport bounding box before
     * a re-render.
     */
    prevViewportBox?: AxisBox2D;
    /**
     * The overall scale of the local coordinate system as transformed by all parents
     * of this component. We use this for scale correction on our calculated layouts
     * and scale-affected values like `boxShadow`.
     *
     * This is considered mutable to avoid object creation on each frame.
     */
    treeScale: Point2D;
    private prevTreeScale;
    /**
     * The delta between the boxCorrected and the desired
     * targetBox (before user-set transforms are applied). The calculated output will be
     * handed to the renderer and used as part of the style correction calculations, for
     * instance calculating how to display the desired border-radius correctly.
     *
     * This is considered mutable to avoid object creation on each frame.
     */
    delta: BoxDelta;
    /**
     * The delta between the boxCorrected and the desired targetBoxFinal. The calculated
     * output will be handed to the renderer and used to project the boxCorrected into
     * the targetBoxFinal.
     *
     * This is considered mutable to avoid object creation on each frame.
     */
    deltaFinal: BoxDelta;
    /**
     * The computed transform string to apply deltaFinal to the element. Currently this is only
     * being used to diff and decide whether to render on the current frame, but a minor optimisation
     * could be to provide this to the buildHTMLStyle function.
     */
    deltaTransform: string;
    /**
     * If we've got a rotate motion value, we force layout projection calculations
     * to use o layout origin of 0.5 rather than dynamically calculating one based
     * on relative positioning. This is so the component always rotates around its centre rather
     * than an arbitrarily computed point.
     */
    private layoutOrigin;
    /**
     *
     */
    stopLayoutAxisAnimation: {
        x: () => void;
        y: () => void;
    };
    isVisible?: boolean;
    hide(): void;
    show(): void;
    /**
     * Register an event listener to fire when the layout is updated. We might want to expose support
     * for this via a `motion` prop.
     */
    onLayoutUpdate(callback: LayoutUpdateHandler): () => undefined;
    onLayoutMeasure(callback: LayoutUpdateHandler): () => undefined;
    onViewportBoxUpdate(callback: OnViewportBoxUpdate): () => undefined;
    /**
     * To be called when all layouts are successfully updated. In turn we can notify layoutUpdate
     * subscribers.
     */
    layoutReady(config?: SharedLayoutAnimationConfig): void;
    /**
     * Measure and return the Element's bounding box. We convert it to a AxisBox2D
     * structure to make it easier to work on each individual axis generically.
     */
    getBoundingBox(): AxisBox2D;
    getBoundingBoxWithoutTransforms(): AxisBox2D;
    /**
     * Return the computed style after a render.
     */
    getComputedStyle(): CSSStyleDeclaration;
    /**
     * Record the bounding box as it exists before a re-render.
     */
    snapshotBoundingBox(): void;
    rebaseTargetBox(force?: boolean, box?: AxisBox2D): void;
    /**
     * The viewport scroll at the time of the previous layout measurement.
     */
    viewportScroll: Point2D;
    measureLayout(): void;
    isTargetBoxLocked: boolean;
    lockTargetBox(): void;
    unlockTargetBox(): void;
    /**
     * Reset the transform on the current Element. This is called as part
     * of a batched process across the entire layout tree. To remove this write
     * cycle it'd be interesting to see if it's possible to "undo" all the current
     * layout transforms up the tree in the same way this.getBoundingBoxWithoutTransforms
     * works
     */
    resetTransform(): void;
    /**
     * Set new min/max boundaries to project an axis into
     */
    setAxisTarget(axis: "x" | "y", min: number, max: number): void;
    /**
     *
     */
    axisProgress: MotionPoint;
    /**
     *
     */
    startLayoutAxisAnimation(axis: "x" | "y", transition: Transition): Promise<void> | undefined;
    stopLayoutAnimation(): void;
    updateLayoutDelta: () => void;
    /**
     * Update the layout deltas to reflect the relative positions of the layout
     * and the desired target box
     */
    updateLayoutDeltas(): void;
    updateTransformDeltas(): void;
    /**
     * ========================================
     * Build & render
     * ========================================
     */
    /**
     * Build a style prop using the latest resolved MotionValues
     */
    build(): void;
    /**
     * Render the Element by rebuilding and applying the latest styles and vars.
     */
    render(): void;
}
interface MotionPoint {
    x: MotionValue<number>;
    y: MotionValue<number>;
}
export {};
